# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spikesorter.proto

from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import common_pb2 as common__pb2
from . import biointerface_pb2 as biointerface__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='spikesorter.proto',
  package='allego',
  syntax='proto2',
  serialized_options=b'Z\023internal/radix/grpc',
  serialized_pb=b'\n\x11spikesorter.proto\x12\x06\x61llego\x1a\x0c\x63ommon.proto\x1a\x12\x62iointerface.proto\"\x84\x02\n\x18SpikeSorterLaunchRequest\x12\x11\n\tdsourceID\x18\x01 \x01(\t\x12&\n\x06source\x18\x02 \x01(\x0b\x32\x16.allego.FileDescriptor\x12\x1b\n\x13maxNumSiteNeighbors\x18\x04 \x01(\x05\x12\x18\n\x10neighborRadiusUm\x18\x05 \x01(\x01\x12/\n\x07variant\x18\x06 \x03(\x0b\x32\x1e.allego.SpikeSorterVariantSpec\x12%\n\x04mode\x18\x07 \x01(\x0e\x32\x17.allego.SpikeSorterMode\x12\x0c\n\x04seed\x18\x08 \x01(\x03\x12\x10\n\x08isAutoOn\x18\t \x01(\x08\"\x8a\x01\n\x19SpikeSorterCommandRequest\x12\x15\n\rspikeSorterID\x18\x01 \x02(\t\x12\'\n\x03\x63md\x18\x02 \x02(\x0e\x32\x1a.allego.SpikeSorterCommand\x12-\n\x06subCmd\x18\x03 \x02(\x0e\x32\x1d.allego.SpikeSorterSubCommand\"\xcf\x01\n\x10SpikeSorterState\x12+\n\x03sys\x18\x01 \x02(\x0e\x32\x1e.allego.SpikeSorterStateSystem\x12\x14\n\x0c\x66racComplete\x18\x02 \x01(\x01\x12\x0b\n\x03msg\x18\x03 \x01(\t\x12\x12\n\nlaunchTime\x18\x04 \x01(\t\x12\x16\n\x0einitializeTime\x18\x05 \x01(\t\x12\x18\n\x10sessionStartTime\x18\x06 \x01(\t\x12\x17\n\x0fsessionStopTime\x18\x07 \x01(\t\x12\x0c\n\x04isOn\x18\x08 \x01(\x08\"\x81\x01\n\x0cSpkSortIOreq\x12#\n\x04type\x18\x01 \x02(\x0e\x32\x15.allego.SpkSortIOtype\x12\'\n\x06target\x18\x02 \x02(\x0e\x32\x17.allego.SpkSortIOtarget\x12#\n\x04mode\x18\x03 \x02(\x0e\x32\x15.allego.SpkSortIOmode\"i\n\x16SpikeSorterLaunchReply\x12\x15\n\rspikeSorterID\x18\x01 \x02(\t\x12+\n\nsorterType\x18\x02 \x02(\x0e\x32\x17.allego.SpikeSorterType\x12\x0b\n\x03msg\x18\x03 \x01(\t\"0\n\x16GetSpikeSorterIDsReply\x12\x16\n\x0espikeSorterIDs\x18\x01 \x03(\t\"\xa1\x01\n\x1fSpikeSorterGetRasterDataRequest\x12\x15\n\rspikeSorterID\x18\x01 \x02(\t\x12\x12\n\nntvChanIdx\x18\x02 \x03(\x05\x12\x12\n\ntimeWindow\x18\x03 \x02(\x01\x12\x17\n\x0fplotWidthPoints\x18\x04 \x02(\x01\x12\x13\n\x0b\x63omponentID\x18\x05 \x02(\t\x12\x11\n\ttimeRange\x18\x06 \x03(\x01\"\xaa\x01\n\x1aSpikeSorterRasterDataReply\x12<\n\x18spikeTimestampsByChannel\x18\x02 \x03(\x0b\x32\x1a.allego.SpikeTimestampData\x12\x11\n\ttimeRange\x18\x03 \x03(\x01\x12\x16\n\x0etimeStampRange\x18\x04 \x03(\x03\x12\x10\n\x08GPIOData\x18\x05 \x02(\x0c\x12\x11\n\tGPIOShape\x18\x06 \x03(\x05\"3\n\x1aSpikeSorterStandardRequest\x12\x15\n\rspikeSorterID\x18\x01 \x02(\t\"\x86\x03\n\x12SpikeSorterDynamic\x12\x11\n\tisEnabled\x18\x01 \x01(\x08\x12\x43\n\x0fupdatePeriodSec\x18\x02 \x01(\x0b\x32*.allego.SpikeSorterDynamic.UpdatePeriodSec\x12\x35\n\x08\x63riteria\x18\x03 \x01(\x0b\x32#.allego.SpikeSorterDynamic.Criteria\x1a\xa0\x01\n\x08\x43riteria\x12\x31\n\x06\x64\x65tect\x18\x01 \x01(\x0e\x32!.allego.SpikeSorterCriterionLevel\x12\x30\n\x05train\x18\x02 \x01(\x0e\x32!.allego.SpikeSorterCriterionLevel\x12/\n\x04sort\x18\x03 \x01(\x0e\x32!.allego.SpikeSorterCriterionLevel\x1a>\n\x0fUpdatePeriodSec\x12\x0e\n\x06\x64\x65tect\x18\x01 \x01(\x01\x12\r\n\x05train\x18\x02 \x01(\x01\x12\x0c\n\x04sort\x18\x03 \x01(\x01\"\xc5\x01\n\x1cSpikeSorterSetDynamicRequest\x12\x15\n\rspikeSorterID\x18\x01 \x02(\t\x12\x42\n\x07variant\x18\x02 \x03(\x0b\x32\x31.allego.SpikeSorterSetDynamicRequest.VariantEntry\x1aJ\n\x0cVariantEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12)\n\x05value\x18\x02 \x01(\x0b\x32\x1a.allego.SpikeSorterDynamic:\x02\x38\x01\"\xd8\x01\n\x1aSpikeSorterGetDynamicReply\x12\x15\n\rspikeSorterID\x18\x01 \x02(\t\x12\x15\n\rrootVariantID\x18\x02 \x02(\t\x12@\n\x07variant\x18\x03 \x03(\x0b\x32/.allego.SpikeSorterGetDynamicReply.VariantEntry\x1aJ\n\x0cVariantEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12)\n\x05value\x18\x02 \x01(\x0b\x32\x1a.allego.SpikeSorterDynamic:\x02\x38\x01\"l\n\x1fGetSpikeSorterParamCommandReply\x12\x15\n\rspikeSorterID\x18\x01 \x02(\t\x12\x32\n\x03rec\x18\x02 \x03(\x0b\x32%.allego.SpikeSorterParamCommandRecord\"3\n\x12\x43lusterMapOutliers\x12\x0c\n\x04mild\x18\x01 \x03(\x01\x12\x0f\n\x07\x65xtreme\x18\x02 \x03(\x01\"9\n\x13\x43lusterMapQuartiles\x12\n\n\x02q1\x18\x01 \x02(\x01\x12\n\n\x02q2\x18\x02 \x02(\x01\x12\n\n\x02q3\x18\x03 \x02(\x01\"\x83\x01\n\x0f\x43lusterMapStats\x12\x16\n\x0e\x63\x65ntroidCenter\x18\x01 \x03(\x01\x12\x12\n\ncentroidSd\x18\x02 \x03(\x01\x12\x16\n\x0e\x63\x65ntroidSdNorm\x18\x03 \x02(\x01\x12\x19\n\x11intraCentroidDist\x18\x04 \x03(\x01\x12\x11\n\tnumSpikes\x18\x05 \x02(\x03\"f\n\x10\x43lusterMapRecord\x12\r\n\x05label\x18\x01 \x02(\x05\x12&\n\x05stats\x18\x03 \x02(\x0b\x32\x17.allego.ClusterMapStats\x12\x1b\n\x13numSpikesTrainCache\x18\x04 \x02(\x03\"\xa8\x01\n\x13SpikeSortSiteStatus\x12\x12\n\nntvChanIdx\x18\x01 \x02(\x05\x12\x15\n\rorderedLabels\x18\x02 \x03(\x05\x12)\n\x07\x63luster\x18\x03 \x03(\x0b\x32\x18.allego.ClusterMapRecord\x12\x11\n\tnumSpikes\x18\x04 \x03(\x03\x12\x0c\n\x04zeta\x18\x05 \x03(\x01\x12\x1a\n\x12\x61ggregateSpikeRate\x18\x06 \x02(\x01\"\x8f\x01\n\x14SpikeSortPhaseStatus\x12\x11\n\ttimeRange\x18\x01 \x03(\x01\x12\x12\n\nchunkIndex\x18\x02 \x02(\x03\x12\x14\n\x0cupdatePeriod\x18\x03 \x02(\x01\x12\x0c\n\x04\x62\x65ta\x18\x04 \x02(\x01\x12\x12\n\nisComplete\x18\x05 \x02(\x08\x12\x18\n\x10\x66ractionComplete\x18\x06 \x02(\x01\"*\n\x13SpikeSortNbrIdxList\x12\x13\n\x0bntvChanIdxs\x18\x01 \x03(\x05\"\xf2\x02\n\x16SpikeSorterStatusReply\x12\'\n\x05state\x18\x01 \x02(\x0b\x32\x18.allego.SpikeSorterState\x12\x16\n\x0e\x62iointerfaceID\x18\x03 \x02(\t\x12\x14\n\x0c\x64\x61tasourceID\x18\x04 \x02(\t\x12\x10\n\x08sampFreq\x18\x05 \x02(\x01\x12\x19\n\x11\x65nabledNtvChanIdx\x18\x06 \x03(\x05\x12+\n\x05phase\x18\x07 \x03(\x0b\x32\x1c.allego.SpikeSortPhaseStatus\x12\x30\n\x0b\x65nabledSite\x18\x08 \x03(\x0b\x32\x1b.allego.SpikeSortSiteStatus\x12\x12\n\nprobeYield\x18\t \x02(\x01\x12\x11\n\tsortStats\x18\n \x03(\x01\x12\x1b\n\x13\x64\x61tasourceTimeRange\x18\x0c \x03(\x01\x12\x1d\n\x15\x62iointerfaceTimeRange\x18\r \x03(\x01\x12\x12\n\nnumNeurons\x18\x0f \x02(\x03\"R\n\x1eSpikeSorterStatusVariantsReply\x12\x30\n\x08variants\x18\x01 \x03(\x0b\x32\x1e.allego.SpikeSorterStatusReply\"\xfd\x02\n\x19SpikeSorterClassifierSpec\x12\r\n\x05\x61lpha\x18\x01 \x02(\x01\x12\x11\n\talphaBias\x18\x02 \x02(\x01\x12\x16\n\x0e\x64imOutputLayer\x18\x03 \x02(\x05\x12\x16\n\x0e\x65rrorTolerance\x18\x04 \x02(\x01\x12\x19\n\x11hiddenLayerFactor\x18\x05 \x02(\x01\x12\n\n\x02iD\x18\x06 \x02(\t\x12\x16\n\x0einitBiasStdDev\x18\x07 \x02(\x01\x12\x18\n\x10initWeightStdDev\x18\x08 \x02(\x01\x12\x11\n\tisMasking\x18\t \x02(\x08\x12\x10\n\x08l1lambda\x18\n \x02(\x01\x12\x15\n\rminibatchSize\x18\x0b \x02(\x05\x12\x15\n\rmaxNumSamples\x18\x0c \x02(\x05\x12\x11\n\tnumEpochs\x18\r \x02(\x05\x12\x19\n\x11numSamplesTestMSE\x18\x0e \x02(\x05\x12\x1b\n\x13numConcurrentModels\x18\x0f \x02(\x05\x12\x17\n\x0flabelNoiseLevel\x18\x10 \x02(\x01\"u\n\x16SpikeSorterVariantSpec\x12\n\n\x02iD\x18\x01 \x02(\t\x12\x14\n\x0csiteConfigID\x18\x02 \x02(\t\x12\x39\n\x0e\x63lassifierSpec\x18\x03 \x02(\x0b\x32!.allego.SpikeSorterClassifierSpec\"\xcc\x01\n\x0fSpikeSorterSpec\x12\x15\n\rspikeSorterID\x18\x01 \x02(\t\x12\x14\n\x0c\x64\x61tasourceID\x18\x02 \x02(\t\x12\x16\n\x0e\x62iointerfaceID\x18\x03 \x02(\t\x12\x1b\n\x13maxNumSiteNeighbors\x18\x04 \x02(\x05\x12\x18\n\x10neighborRadiusUm\x18\x05 \x02(\x01\x12/\n\x07variant\x18\x06 \x03(\x0b\x32\x1e.allego.SpikeSorterVariantSpec\x12\x0c\n\x04seed\x18\x08 \x02(\x03\"\xc2\x01\n\x19SpikeSorterGetConfigReply\x12%\n\x04spec\x18\x01 \x02(\x0b\x32\x17.allego.SpikeSorterSpec\x12\x16\n\x0e\x61IupdatePeriod\x18\x02 \x02(\x01\x12\x19\n\x11orderedVariantIDs\x18\x03 \x03(\t\x12\x15\n\rrootVariantID\x18\x04 \x02(\t\x12\x34\n\x0csorterStatus\x18\x06 \x03(\x0b\x32\x1e.allego.SpikeSorterStatusReply\"\x90\x02\n\x15SpikeSorterVizRequest\x12\x15\n\rspikeSorterID\x18\x01 \x02(\t\x12\x11\n\tvariantID\x18\x02 \x02(\t\x12\x12\n\nntvChanIdx\x18\x03 \x03(\x05\x12\x13\n\x0bspikeLabels\x18\x04 \x03(\x05\x12\x34\n\x07vizType\x18\x05 \x02(\x0e\x32#.allego.SpikeSorterVizRequest.VType\x12\x14\n\x0cisYAutoScale\x18\x06 \x02(\x08\x12\x0c\n\x04yLim\x18\x07 \x03(\x01\x12\x0e\n\x06\x66igDir\x18\x08 \x02(\t\x12\x11\n\tnumSpikes\x18\t \x02(\x05\"\'\n\x05VType\x12\x1e\n\x1aVIZ_SPIKESORT_TRAIN_SPIKES\x10\x00\"\xc2\x05\n\x1cSpikeSorterGetDashboardReply\x12\"\n\x0c\x65nabledPorts\x18\x01 \x03(\x0e\x32\x0c.allego.Port\x12\x37\n\x07general\x18\x02 \x02(\x0b\x32&.allego.SpikeSorterDashboardGeneralRec\x12\x33\n\tsiteStats\x18\x03 \x02(\x0b\x32 .allego.IndicoDashboardSiteStats\x12\x46\n\tportStats\x18\x04 \x03(\x0b\x32\x33.allego.SpikeSorterGetDashboardReply.PortStatsEntry\x12\x46\n\tsitePanel\x18\x05 \x03(\x0b\x32\x33.allego.SpikeSorterGetDashboardReply.SitePanelEntry\x12J\n\x0bneuronPanel\x18\x06 \x03(\x0b\x32\x35.allego.SpikeSorterGetDashboardReply.NeuronPanelEntry\x12*\n\x02\x61I\x18\x07 \x01(\x0b\x32\x1e.allego.SpikeSorterDashboardAI\x1aR\n\x0ePortStatsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12/\n\x05value\x18\x02 \x01(\x0b\x32 .allego.IndicoDashboardPortStats:\x02\x38\x01\x1aW\n\x0eSitePanelEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x34\n\x05value\x18\x02 \x01(\x0b\x32%.allego.IndicoDashboardSiteIndicators:\x02\x38\x01\x1a[\n\x10NeuronPanelEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x36\n\x05value\x18\x02 \x01(\x0b\x32\'.allego.IndicoDashboardNeuronIndicators:\x02\x38\x01\"\xac\x03\n\x1eSpikeSorterDashboardGeneralRec\x12\'\n\x05state\x18\x01 \x02(\x0b\x32\x18.allego.SpikeSorterState\x12+\n\nsorterType\x18\x02 \x02(\x0e\x32\x17.allego.SpikeSorterType\x12\x10\n\x08sorterID\x18\x03 \x02(\t\x12\x14\n\x0c\x64\x61tasourceID\x18\x04 \x02(\t\x12\x11\n\ttimeRange\x18\x05 \x03(\x01\x12\x15\n\rnumTotalSites\x18\x06 \x02(\x03\x12\x17\n\x0fnumEnabledSites\x18\x07 \x02(\x03\x12\x16\n\x0enumActiveSites\x18\x08 \x02(\x03\x12\x12\n\nnumNeurons\x18\t \x02(\x03\x12\x12\n\nprobeYield\x18\n \x02(\x01\x12\x11\n\tsiteYield\x18\x0b \x02(\x01\x12\x1a\n\x12numSpikesProcessed\x18\x0c \x02(\x03\x12\x18\n\x10numSpikesLabeled\x18\r \x02(\x03\x12\x16\n\x0esortEfficiency\x18\x0e \x02(\x01\x12(\n\x08sinkDesc\x18\x0f \x02(\x0b\x32\x16.allego.FileDescriptor\"\xd5\x01\n\x16SpikeSorterDashboardAI\x12\x0c\n\x04\x62\x65ta\x18\x01 \x02(\x01\x12\"\n\x1a\x65stimatedReaderCompleteSec\x18\x02 \x02(\x01\x12\x1a\n\x12interSessionDurSec\x18\x03 \x02(\x01\x12\x19\n\x11interSessionStart\x18\x04 \x02(\t\x12\x15\n\rsessionDurSec\x18\x05 \x02(\x01\x12\x14\n\x0csessionStart\x18\x06 \x02(\t\x12\x12\n\nsessionIdx\x18\x07 \x02(\x03\x12\x11\n\tstartTime\x18\x08 \x02(\t\"_\n\x18IndicoDashboardSiteStats\x12\x0b\n\x03snr\x18\x01 \x03(\x01\x12\r\n\x05noise\x18\x02 \x03(\x01\x12\x13\n\x0bneuronYield\x18\x03 \x03(\x01\x12\x12\n\nnumNeurons\x18\x04 \x02(\x03\"\x90\x01\n\x18IndicoDashboardPortStats\x12\x0b\n\x03snr\x18\x01 \x03(\x01\x12\r\n\x05noise\x18\x02 \x03(\x01\x12\x13\n\x0bneuronYield\x18\x03 \x03(\x01\x12\x16\n\x0esortEfficiency\x18\x04 \x02(\x01\x12\x17\n\x0fnumEnabledSites\x18\x05 \x02(\x03\x12\x12\n\nnumNeurons\x18\x06 \x02(\x03\"\xd9\x01\n\x1dIndicoDashboardSiteIndicators\x12\x12\n\nntvChanIdx\x18\x01 \x03(\x05\x12\x0b\n\x03snr\x18\x02 \x03(\x01\x12\r\n\x05noise\x18\x03 \x03(\x01\x12\x13\n\x0bneuronYield\x18\x04 \x03(\x01\x12\x16\n\x0esortEfficiency\x18\x05 \x03(\x01\x12\x11\n\tspikeRate\x18\x06 \x03(\x01\x12\x11\n\tposProbeX\x18\x07 \x03(\x01\x12\x11\n\tposProbeY\x18\x08 \x03(\x01\x12\x11\n\tposProbeZ\x18\t \x03(\x01\x12\x0f\n\x07siteNum\x18\n \x03(\x05\"\xb1\x01\n\x1fIndicoDashboardNeuronIndicators\x12\x10\n\x08neuronID\x18\x01 \x03(\t\x12\x0b\n\x03snr\x18\x02 \x03(\x01\x12\x11\n\tspikeRate\x18\x03 \x03(\x01\x12\x11\n\tposProbeX\x18\x04 \x03(\x01\x12\x11\n\tposProbeY\x18\x05 \x03(\x01\x12\x11\n\tposProbeZ\x18\x06 \x03(\x01\x12\x0f\n\x07siteNum\x18\x07 \x03(\x05\x12\x12\n\nspikeLabel\x18\x08 \x03(\x05\"\xa7\x02\n\x1cSpikeSorterDashboardSiteDesc\x12\x1a\n\x04port\x18\x01 \x02(\x0e\x32\x0c.allego.Port\x12\x12\n\nntvChanIdx\x18\x02 \x02(\x05\x12\x10\n\x08posProbe\x18\x03 \x03(\x01\x12\x10\n\x08posBrain\x18\x04 \x03(\x01\x12\x0e\n\x06snrMax\x18\x05 \x02(\x01\x12\x0e\n\x06snrMin\x18\x06 \x02(\x01\x12\x12\n\nnoiseLevel\x18\x07 \x02(\x01\x12\x12\n\nnumNeurons\x18\x08 \x02(\x03\x12/\n\rindicoCluster\x18\n \x03(\x0b\x32\x18.allego.ClusterMapRecord\x12\x1c\n\x14pileWaveformMinValue\x18\r \x02(\x02\x12\x1c\n\x14pileWaveformMaxValue\x18\x0e \x02(\x02\"\xd2\x01\n\x1eSpikeSorterDashboardNeuronDesc\x12\x1a\n\x04port\x18\x01 \x02(\x0e\x32\x0c.allego.Port\x12&\n\x04\x64\x65sc\x18\x02 \x02(\x0b\x32\x18.allego.NeuronDescriptor\x12\x0b\n\x03snr\x18\x05 \x02(\x01\x12\x0f\n\x07IsihMax\x18\x06 \x02(\x01\x12\x15\n\rIsihArgmaxSec\x18\x07 \x02(\x01\x12\x15\n\rIsihArgmaxIdx\x18\x08 \x02(\x03\x12\x10\n\x08IsihMean\x18\t \x02(\x01\x12\x0e\n\x06IsihSd\x18\n \x02(\x01\"\xfa\x01\n SpikeSorterDashboardNeuronDetail\x12&\n\x04\x64\x65sc\x18\x01 \x02(\x0b\x32\x18.allego.NeuronDescriptor\x12\x18\n\x10templateWaveform\x18\x02 \x03(\x02\x12\x1a\n\x12templateSdWaveform\x18\x03 \x03(\x02\x12\x18\n\x10pileWaveformData\x18\x04 \x03(\x02\x12\x1e\n\x16numSamplesPileWaveform\x18\x05 \x02(\x05\x12\x18\n\x10numPileWaveforms\x18\x06 \x02(\x05\x12$\n\x04isih\x18\x0b \x02(\x0b\x32\x16.allego.NeuronHistData\"\xa9\x01\n\x1eSpikeSorterDashboardSiteDetail\x12\x32\n\x04\x64\x65sc\x18\x01 \x02(\x0b\x32$.allego.SpikeSorterDashboardSiteDesc\x12\x19\n\x11orderedSpikeLabel\x18\x02 \x03(\x05\x12\x38\n\x06neuron\x18\x03 \x03(\x0b\x32(.allego.SpikeSorterDashboardNeuronDetail*\x80\x01\n\x0fSpikeSorterType\x12\x0f\n\x0bSORTER_NULL\x10\x00\x12\x15\n\x11SORTER_VEX_STREAM\x10\x01\x12\x18\n\x14SORTER_SPIKES_STREAM\x10\x02\x12\x13\n\x0fSORTER_VEX_FILE\x10\x03\x12\x16\n\x12SORTER_SPIKES_FILE\x10\x04*\xb0\x01\n\x12SpikeSorterCommand\x12\x11\n\rSORTER_CMD_ON\x10\x00\x12\x12\n\x0eSORTER_CMD_OFF\x10\x01\x12\x19\n\x15SORTER_CMD_CLEAR_SORT\x10\x02\x12\x15\n\x11SORTER_CMD_REBASE\x10\x04\x12\x13\n\x0fSORTER_CMD_INIT\x10\x07\x12\x17\n\x13SORTER_CMD_LOCALIZE\x10\x08\x12\x13\n\x0fSORTER_CMD_SORT\x10\t*/\n\x15SpikeSorterSubCommand\x12\x16\n\x12SORTER_SUBCMD_NULL\x10\x00*@\n\x0fSpikeSorterMode\x12\x16\n\x12SORTER_MODE_STREAM\x10\x00\x12\x15\n\x11SORTER_MODE_BATCH\x10\x01*I\n\x16SpikeSorterStateSystem\x12\n\n\x06SYS_ON\x10\x00\x12\x0b\n\x07SYS_OFF\x10\x01\x12\x16\n\x12SYS_NOT_CONFIGURED\x10\x02*f\n\rSpkSortIOtype\x12\x17\n\x13SPK_SORT_IO_NETWORK\x10\x00\x12\x17\n\x13SPK_SORT_IO_TRAINER\x10\x01\x12#\n\x1fSPK_SORT_IO_NETWORK_AND_TRAINER\x10\x02*>\n\x0fSpkSortIOtarget\x12\x14\n\x10SPK_SORT_IO_FSYS\x10\x00\x12\x15\n\x11SPK_SORT_IO_CLOUD\x10\x01*;\n\rSpkSortIOmode\x12\x14\n\x10SPK_SORT_IO_SAVE\x10\x00\x12\x14\n\x10SPK_SORT_IO_LOAD\x10\x01*u\n\x19SpikeSorterCriterionLevel\x12\x10\n\x0cSORTER_LEAST\x10\x00\x12\x0f\n\x0bSORTER_LESS\x10\x01\x12\x13\n\x0fSORTER_BALANCED\x10\x02\x12\x0f\n\x0bSORTER_MORE\x10\x03\x12\x0f\n\x0bSORTER_MOST\x10\x04*\x84\x01\n\x07SS_STAT\x12\x08\n\x04MEAN\x10\x00\x12\x06\n\x02SD\x10\x01\x12\x08\n\x04MODE\x10\x02\x12\x07\n\x03MIN\x10\x03\x12\x07\n\x03MAX\x10\x04\x12\x0e\n\nMODE_COUNT\x10\x05\x12\n\n\x06MEDIAN\x10\x06\x12\x07\n\x03Q25\x10\x07\x12\x07\n\x03Q75\x10\x08\x12\x08\n\x04SKEW\x10\t\x12\x0c\n\x08KURTOSIS\x10\n\x12\x05\n\x01N\x10\x0b\x42\x15Z\x13internal/radix/grpc'
  ,
  dependencies=[common__pb2.DESCRIPTOR,biointerface__pb2.DESCRIPTOR,])

_SPIKESORTERTYPE = _descriptor.EnumDescriptor(
  name='SpikeSorterType',
  full_name='allego.SpikeSorterType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SORTER_NULL', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SORTER_VEX_STREAM', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SORTER_SPIKES_STREAM', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SORTER_VEX_FILE', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SORTER_SPIKES_FILE', index=4, number=4,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=7565,
  serialized_end=7693,
)
_sym_db.RegisterEnumDescriptor(_SPIKESORTERTYPE)

SpikeSorterType = enum_type_wrapper.EnumTypeWrapper(_SPIKESORTERTYPE)
_SPIKESORTERCOMMAND = _descriptor.EnumDescriptor(
  name='SpikeSorterCommand',
  full_name='allego.SpikeSorterCommand',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SORTER_CMD_ON', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SORTER_CMD_OFF', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SORTER_CMD_CLEAR_SORT', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SORTER_CMD_REBASE', index=3, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SORTER_CMD_INIT', index=4, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SORTER_CMD_LOCALIZE', index=5, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SORTER_CMD_SORT', index=6, number=9,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=7696,
  serialized_end=7872,
)
_sym_db.RegisterEnumDescriptor(_SPIKESORTERCOMMAND)

SpikeSorterCommand = enum_type_wrapper.EnumTypeWrapper(_SPIKESORTERCOMMAND)
_SPIKESORTERSUBCOMMAND = _descriptor.EnumDescriptor(
  name='SpikeSorterSubCommand',
  full_name='allego.SpikeSorterSubCommand',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SORTER_SUBCMD_NULL', index=0, number=0,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=7874,
  serialized_end=7921,
)
_sym_db.RegisterEnumDescriptor(_SPIKESORTERSUBCOMMAND)

SpikeSorterSubCommand = enum_type_wrapper.EnumTypeWrapper(_SPIKESORTERSUBCOMMAND)
_SPIKESORTERMODE = _descriptor.EnumDescriptor(
  name='SpikeSorterMode',
  full_name='allego.SpikeSorterMode',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SORTER_MODE_STREAM', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SORTER_MODE_BATCH', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=7923,
  serialized_end=7987,
)
_sym_db.RegisterEnumDescriptor(_SPIKESORTERMODE)

SpikeSorterMode = enum_type_wrapper.EnumTypeWrapper(_SPIKESORTERMODE)
_SPIKESORTERSTATESYSTEM = _descriptor.EnumDescriptor(
  name='SpikeSorterStateSystem',
  full_name='allego.SpikeSorterStateSystem',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SYS_ON', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SYS_OFF', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SYS_NOT_CONFIGURED', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=7989,
  serialized_end=8062,
)
_sym_db.RegisterEnumDescriptor(_SPIKESORTERSTATESYSTEM)

SpikeSorterStateSystem = enum_type_wrapper.EnumTypeWrapper(_SPIKESORTERSTATESYSTEM)
_SPKSORTIOTYPE = _descriptor.EnumDescriptor(
  name='SpkSortIOtype',
  full_name='allego.SpkSortIOtype',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SPK_SORT_IO_NETWORK', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SPK_SORT_IO_TRAINER', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SPK_SORT_IO_NETWORK_AND_TRAINER', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=8064,
  serialized_end=8166,
)
_sym_db.RegisterEnumDescriptor(_SPKSORTIOTYPE)

SpkSortIOtype = enum_type_wrapper.EnumTypeWrapper(_SPKSORTIOTYPE)
_SPKSORTIOTARGET = _descriptor.EnumDescriptor(
  name='SpkSortIOtarget',
  full_name='allego.SpkSortIOtarget',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SPK_SORT_IO_FSYS', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SPK_SORT_IO_CLOUD', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=8168,
  serialized_end=8230,
)
_sym_db.RegisterEnumDescriptor(_SPKSORTIOTARGET)

SpkSortIOtarget = enum_type_wrapper.EnumTypeWrapper(_SPKSORTIOTARGET)
_SPKSORTIOMODE = _descriptor.EnumDescriptor(
  name='SpkSortIOmode',
  full_name='allego.SpkSortIOmode',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SPK_SORT_IO_SAVE', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SPK_SORT_IO_LOAD', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=8232,
  serialized_end=8291,
)
_sym_db.RegisterEnumDescriptor(_SPKSORTIOMODE)

SpkSortIOmode = enum_type_wrapper.EnumTypeWrapper(_SPKSORTIOMODE)
_SPIKESORTERCRITERIONLEVEL = _descriptor.EnumDescriptor(
  name='SpikeSorterCriterionLevel',
  full_name='allego.SpikeSorterCriterionLevel',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SORTER_LEAST', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SORTER_LESS', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SORTER_BALANCED', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SORTER_MORE', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SORTER_MOST', index=4, number=4,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=8293,
  serialized_end=8410,
)
_sym_db.RegisterEnumDescriptor(_SPIKESORTERCRITERIONLEVEL)

SpikeSorterCriterionLevel = enum_type_wrapper.EnumTypeWrapper(_SPIKESORTERCRITERIONLEVEL)
_SS_STAT = _descriptor.EnumDescriptor(
  name='SS_STAT',
  full_name='allego.SS_STAT',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='MEAN', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SD', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MODE', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MIN', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MAX', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MODE_COUNT', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MEDIAN', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Q25', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Q75', index=8, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SKEW', index=9, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='KURTOSIS', index=10, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='N', index=11, number=11,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=8413,
  serialized_end=8545,
)
_sym_db.RegisterEnumDescriptor(_SS_STAT)

SS_STAT = enum_type_wrapper.EnumTypeWrapper(_SS_STAT)
SORTER_NULL = 0
SORTER_VEX_STREAM = 1
SORTER_SPIKES_STREAM = 2
SORTER_VEX_FILE = 3
SORTER_SPIKES_FILE = 4
SORTER_CMD_ON = 0
SORTER_CMD_OFF = 1
SORTER_CMD_CLEAR_SORT = 2
SORTER_CMD_REBASE = 4
SORTER_CMD_INIT = 7
SORTER_CMD_LOCALIZE = 8
SORTER_CMD_SORT = 9
SORTER_SUBCMD_NULL = 0
SORTER_MODE_STREAM = 0
SORTER_MODE_BATCH = 1
SYS_ON = 0
SYS_OFF = 1
SYS_NOT_CONFIGURED = 2
SPK_SORT_IO_NETWORK = 0
SPK_SORT_IO_TRAINER = 1
SPK_SORT_IO_NETWORK_AND_TRAINER = 2
SPK_SORT_IO_FSYS = 0
SPK_SORT_IO_CLOUD = 1
SPK_SORT_IO_SAVE = 0
SPK_SORT_IO_LOAD = 1
SORTER_LEAST = 0
SORTER_LESS = 1
SORTER_BALANCED = 2
SORTER_MORE = 3
SORTER_MOST = 4
MEAN = 0
SD = 1
MODE = 2
MIN = 3
MAX = 4
MODE_COUNT = 5
MEDIAN = 6
Q25 = 7
Q75 = 8
SKEW = 9
KURTOSIS = 10
N = 11


_SPIKESORTERVIZREQUEST_VTYPE = _descriptor.EnumDescriptor(
  name='VType',
  full_name='allego.SpikeSorterVizRequest.VType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='VIZ_SPIKESORT_TRAIN_SPIKES', index=0, number=0,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=4587,
  serialized_end=4626,
)
_sym_db.RegisterEnumDescriptor(_SPIKESORTERVIZREQUEST_VTYPE)


_SPIKESORTERLAUNCHREQUEST = _descriptor.Descriptor(
  name='SpikeSorterLaunchRequest',
  full_name='allego.SpikeSorterLaunchRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='dsourceID', full_name='allego.SpikeSorterLaunchRequest.dsourceID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='source', full_name='allego.SpikeSorterLaunchRequest.source', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='maxNumSiteNeighbors', full_name='allego.SpikeSorterLaunchRequest.maxNumSiteNeighbors', index=2,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='neighborRadiusUm', full_name='allego.SpikeSorterLaunchRequest.neighborRadiusUm', index=3,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='variant', full_name='allego.SpikeSorterLaunchRequest.variant', index=4,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mode', full_name='allego.SpikeSorterLaunchRequest.mode', index=5,
      number=7, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='seed', full_name='allego.SpikeSorterLaunchRequest.seed', index=6,
      number=8, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='isAutoOn', full_name='allego.SpikeSorterLaunchRequest.isAutoOn', index=7,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=64,
  serialized_end=324,
)


_SPIKESORTERCOMMANDREQUEST = _descriptor.Descriptor(
  name='SpikeSorterCommandRequest',
  full_name='allego.SpikeSorterCommandRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='spikeSorterID', full_name='allego.SpikeSorterCommandRequest.spikeSorterID', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cmd', full_name='allego.SpikeSorterCommandRequest.cmd', index=1,
      number=2, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='subCmd', full_name='allego.SpikeSorterCommandRequest.subCmd', index=2,
      number=3, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=327,
  serialized_end=465,
)


_SPIKESORTERSTATE = _descriptor.Descriptor(
  name='SpikeSorterState',
  full_name='allego.SpikeSorterState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sys', full_name='allego.SpikeSorterState.sys', index=0,
      number=1, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fracComplete', full_name='allego.SpikeSorterState.fracComplete', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='msg', full_name='allego.SpikeSorterState.msg', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='launchTime', full_name='allego.SpikeSorterState.launchTime', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='initializeTime', full_name='allego.SpikeSorterState.initializeTime', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sessionStartTime', full_name='allego.SpikeSorterState.sessionStartTime', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sessionStopTime', full_name='allego.SpikeSorterState.sessionStopTime', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='isOn', full_name='allego.SpikeSorterState.isOn', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=468,
  serialized_end=675,
)


_SPKSORTIOREQ = _descriptor.Descriptor(
  name='SpkSortIOreq',
  full_name='allego.SpkSortIOreq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='allego.SpkSortIOreq.type', index=0,
      number=1, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='target', full_name='allego.SpkSortIOreq.target', index=1,
      number=2, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mode', full_name='allego.SpkSortIOreq.mode', index=2,
      number=3, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=678,
  serialized_end=807,
)


_SPIKESORTERLAUNCHREPLY = _descriptor.Descriptor(
  name='SpikeSorterLaunchReply',
  full_name='allego.SpikeSorterLaunchReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='spikeSorterID', full_name='allego.SpikeSorterLaunchReply.spikeSorterID', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sorterType', full_name='allego.SpikeSorterLaunchReply.sorterType', index=1,
      number=2, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='msg', full_name='allego.SpikeSorterLaunchReply.msg', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=809,
  serialized_end=914,
)


_GETSPIKESORTERIDSREPLY = _descriptor.Descriptor(
  name='GetSpikeSorterIDsReply',
  full_name='allego.GetSpikeSorterIDsReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='spikeSorterIDs', full_name='allego.GetSpikeSorterIDsReply.spikeSorterIDs', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=916,
  serialized_end=964,
)


_SPIKESORTERGETRASTERDATAREQUEST = _descriptor.Descriptor(
  name='SpikeSorterGetRasterDataRequest',
  full_name='allego.SpikeSorterGetRasterDataRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='spikeSorterID', full_name='allego.SpikeSorterGetRasterDataRequest.spikeSorterID', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ntvChanIdx', full_name='allego.SpikeSorterGetRasterDataRequest.ntvChanIdx', index=1,
      number=2, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timeWindow', full_name='allego.SpikeSorterGetRasterDataRequest.timeWindow', index=2,
      number=3, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='plotWidthPoints', full_name='allego.SpikeSorterGetRasterDataRequest.plotWidthPoints', index=3,
      number=4, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='componentID', full_name='allego.SpikeSorterGetRasterDataRequest.componentID', index=4,
      number=5, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timeRange', full_name='allego.SpikeSorterGetRasterDataRequest.timeRange', index=5,
      number=6, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=967,
  serialized_end=1128,
)


_SPIKESORTERRASTERDATAREPLY = _descriptor.Descriptor(
  name='SpikeSorterRasterDataReply',
  full_name='allego.SpikeSorterRasterDataReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='spikeTimestampsByChannel', full_name='allego.SpikeSorterRasterDataReply.spikeTimestampsByChannel', index=0,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timeRange', full_name='allego.SpikeSorterRasterDataReply.timeRange', index=1,
      number=3, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timeStampRange', full_name='allego.SpikeSorterRasterDataReply.timeStampRange', index=2,
      number=4, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='GPIOData', full_name='allego.SpikeSorterRasterDataReply.GPIOData', index=3,
      number=5, type=12, cpp_type=9, label=2,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='GPIOShape', full_name='allego.SpikeSorterRasterDataReply.GPIOShape', index=4,
      number=6, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1131,
  serialized_end=1301,
)


_SPIKESORTERSTANDARDREQUEST = _descriptor.Descriptor(
  name='SpikeSorterStandardRequest',
  full_name='allego.SpikeSorterStandardRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='spikeSorterID', full_name='allego.SpikeSorterStandardRequest.spikeSorterID', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1303,
  serialized_end=1354,
)


_SPIKESORTERDYNAMIC_CRITERIA = _descriptor.Descriptor(
  name='Criteria',
  full_name='allego.SpikeSorterDynamic.Criteria',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='detect', full_name='allego.SpikeSorterDynamic.Criteria.detect', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='train', full_name='allego.SpikeSorterDynamic.Criteria.train', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sort', full_name='allego.SpikeSorterDynamic.Criteria.sort', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1523,
  serialized_end=1683,
)

_SPIKESORTERDYNAMIC_UPDATEPERIODSEC = _descriptor.Descriptor(
  name='UpdatePeriodSec',
  full_name='allego.SpikeSorterDynamic.UpdatePeriodSec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='detect', full_name='allego.SpikeSorterDynamic.UpdatePeriodSec.detect', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='train', full_name='allego.SpikeSorterDynamic.UpdatePeriodSec.train', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sort', full_name='allego.SpikeSorterDynamic.UpdatePeriodSec.sort', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1685,
  serialized_end=1747,
)

_SPIKESORTERDYNAMIC = _descriptor.Descriptor(
  name='SpikeSorterDynamic',
  full_name='allego.SpikeSorterDynamic',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='isEnabled', full_name='allego.SpikeSorterDynamic.isEnabled', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='updatePeriodSec', full_name='allego.SpikeSorterDynamic.updatePeriodSec', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='criteria', full_name='allego.SpikeSorterDynamic.criteria', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_SPIKESORTERDYNAMIC_CRITERIA, _SPIKESORTERDYNAMIC_UPDATEPERIODSEC, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1357,
  serialized_end=1747,
)


_SPIKESORTERSETDYNAMICREQUEST_VARIANTENTRY = _descriptor.Descriptor(
  name='VariantEntry',
  full_name='allego.SpikeSorterSetDynamicRequest.VariantEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='allego.SpikeSorterSetDynamicRequest.VariantEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='allego.SpikeSorterSetDynamicRequest.VariantEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1873,
  serialized_end=1947,
)

_SPIKESORTERSETDYNAMICREQUEST = _descriptor.Descriptor(
  name='SpikeSorterSetDynamicRequest',
  full_name='allego.SpikeSorterSetDynamicRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='spikeSorterID', full_name='allego.SpikeSorterSetDynamicRequest.spikeSorterID', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='variant', full_name='allego.SpikeSorterSetDynamicRequest.variant', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_SPIKESORTERSETDYNAMICREQUEST_VARIANTENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1750,
  serialized_end=1947,
)


_SPIKESORTERGETDYNAMICREPLY_VARIANTENTRY = _descriptor.Descriptor(
  name='VariantEntry',
  full_name='allego.SpikeSorterGetDynamicReply.VariantEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='allego.SpikeSorterGetDynamicReply.VariantEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='allego.SpikeSorterGetDynamicReply.VariantEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1873,
  serialized_end=1947,
)

_SPIKESORTERGETDYNAMICREPLY = _descriptor.Descriptor(
  name='SpikeSorterGetDynamicReply',
  full_name='allego.SpikeSorterGetDynamicReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='spikeSorterID', full_name='allego.SpikeSorterGetDynamicReply.spikeSorterID', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rootVariantID', full_name='allego.SpikeSorterGetDynamicReply.rootVariantID', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='variant', full_name='allego.SpikeSorterGetDynamicReply.variant', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_SPIKESORTERGETDYNAMICREPLY_VARIANTENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1950,
  serialized_end=2166,
)


_GETSPIKESORTERPARAMCOMMANDREPLY = _descriptor.Descriptor(
  name='GetSpikeSorterParamCommandReply',
  full_name='allego.GetSpikeSorterParamCommandReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='spikeSorterID', full_name='allego.GetSpikeSorterParamCommandReply.spikeSorterID', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rec', full_name='allego.GetSpikeSorterParamCommandReply.rec', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2168,
  serialized_end=2276,
)


_CLUSTERMAPOUTLIERS = _descriptor.Descriptor(
  name='ClusterMapOutliers',
  full_name='allego.ClusterMapOutliers',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='mild', full_name='allego.ClusterMapOutliers.mild', index=0,
      number=1, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='extreme', full_name='allego.ClusterMapOutliers.extreme', index=1,
      number=2, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2278,
  serialized_end=2329,
)


_CLUSTERMAPQUARTILES = _descriptor.Descriptor(
  name='ClusterMapQuartiles',
  full_name='allego.ClusterMapQuartiles',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='q1', full_name='allego.ClusterMapQuartiles.q1', index=0,
      number=1, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='q2', full_name='allego.ClusterMapQuartiles.q2', index=1,
      number=2, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='q3', full_name='allego.ClusterMapQuartiles.q3', index=2,
      number=3, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2331,
  serialized_end=2388,
)


_CLUSTERMAPSTATS = _descriptor.Descriptor(
  name='ClusterMapStats',
  full_name='allego.ClusterMapStats',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='centroidCenter', full_name='allego.ClusterMapStats.centroidCenter', index=0,
      number=1, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='centroidSd', full_name='allego.ClusterMapStats.centroidSd', index=1,
      number=2, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='centroidSdNorm', full_name='allego.ClusterMapStats.centroidSdNorm', index=2,
      number=3, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='intraCentroidDist', full_name='allego.ClusterMapStats.intraCentroidDist', index=3,
      number=4, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='numSpikes', full_name='allego.ClusterMapStats.numSpikes', index=4,
      number=5, type=3, cpp_type=2, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2391,
  serialized_end=2522,
)


_CLUSTERMAPRECORD = _descriptor.Descriptor(
  name='ClusterMapRecord',
  full_name='allego.ClusterMapRecord',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='label', full_name='allego.ClusterMapRecord.label', index=0,
      number=1, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stats', full_name='allego.ClusterMapRecord.stats', index=1,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='numSpikesTrainCache', full_name='allego.ClusterMapRecord.numSpikesTrainCache', index=2,
      number=4, type=3, cpp_type=2, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2524,
  serialized_end=2626,
)


_SPIKESORTSITESTATUS = _descriptor.Descriptor(
  name='SpikeSortSiteStatus',
  full_name='allego.SpikeSortSiteStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ntvChanIdx', full_name='allego.SpikeSortSiteStatus.ntvChanIdx', index=0,
      number=1, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='orderedLabels', full_name='allego.SpikeSortSiteStatus.orderedLabels', index=1,
      number=2, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cluster', full_name='allego.SpikeSortSiteStatus.cluster', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='numSpikes', full_name='allego.SpikeSortSiteStatus.numSpikes', index=3,
      number=4, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='zeta', full_name='allego.SpikeSortSiteStatus.zeta', index=4,
      number=5, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='aggregateSpikeRate', full_name='allego.SpikeSortSiteStatus.aggregateSpikeRate', index=5,
      number=6, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2629,
  serialized_end=2797,
)


_SPIKESORTPHASESTATUS = _descriptor.Descriptor(
  name='SpikeSortPhaseStatus',
  full_name='allego.SpikeSortPhaseStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='timeRange', full_name='allego.SpikeSortPhaseStatus.timeRange', index=0,
      number=1, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='chunkIndex', full_name='allego.SpikeSortPhaseStatus.chunkIndex', index=1,
      number=2, type=3, cpp_type=2, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='updatePeriod', full_name='allego.SpikeSortPhaseStatus.updatePeriod', index=2,
      number=3, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='beta', full_name='allego.SpikeSortPhaseStatus.beta', index=3,
      number=4, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='isComplete', full_name='allego.SpikeSortPhaseStatus.isComplete', index=4,
      number=5, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fractionComplete', full_name='allego.SpikeSortPhaseStatus.fractionComplete', index=5,
      number=6, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2800,
  serialized_end=2943,
)


_SPIKESORTNBRIDXLIST = _descriptor.Descriptor(
  name='SpikeSortNbrIdxList',
  full_name='allego.SpikeSortNbrIdxList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ntvChanIdxs', full_name='allego.SpikeSortNbrIdxList.ntvChanIdxs', index=0,
      number=1, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2945,
  serialized_end=2987,
)


_SPIKESORTERSTATUSREPLY = _descriptor.Descriptor(
  name='SpikeSorterStatusReply',
  full_name='allego.SpikeSorterStatusReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='state', full_name='allego.SpikeSorterStatusReply.state', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='biointerfaceID', full_name='allego.SpikeSorterStatusReply.biointerfaceID', index=1,
      number=3, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='datasourceID', full_name='allego.SpikeSorterStatusReply.datasourceID', index=2,
      number=4, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sampFreq', full_name='allego.SpikeSorterStatusReply.sampFreq', index=3,
      number=5, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='enabledNtvChanIdx', full_name='allego.SpikeSorterStatusReply.enabledNtvChanIdx', index=4,
      number=6, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='phase', full_name='allego.SpikeSorterStatusReply.phase', index=5,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='enabledSite', full_name='allego.SpikeSorterStatusReply.enabledSite', index=6,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='probeYield', full_name='allego.SpikeSorterStatusReply.probeYield', index=7,
      number=9, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sortStats', full_name='allego.SpikeSorterStatusReply.sortStats', index=8,
      number=10, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='datasourceTimeRange', full_name='allego.SpikeSorterStatusReply.datasourceTimeRange', index=9,
      number=12, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='biointerfaceTimeRange', full_name='allego.SpikeSorterStatusReply.biointerfaceTimeRange', index=10,
      number=13, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='numNeurons', full_name='allego.SpikeSorterStatusReply.numNeurons', index=11,
      number=15, type=3, cpp_type=2, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2990,
  serialized_end=3360,
)


_SPIKESORTERSTATUSVARIANTSREPLY = _descriptor.Descriptor(
  name='SpikeSorterStatusVariantsReply',
  full_name='allego.SpikeSorterStatusVariantsReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='variants', full_name='allego.SpikeSorterStatusVariantsReply.variants', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3362,
  serialized_end=3444,
)


_SPIKESORTERCLASSIFIERSPEC = _descriptor.Descriptor(
  name='SpikeSorterClassifierSpec',
  full_name='allego.SpikeSorterClassifierSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='alpha', full_name='allego.SpikeSorterClassifierSpec.alpha', index=0,
      number=1, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='alphaBias', full_name='allego.SpikeSorterClassifierSpec.alphaBias', index=1,
      number=2, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dimOutputLayer', full_name='allego.SpikeSorterClassifierSpec.dimOutputLayer', index=2,
      number=3, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='errorTolerance', full_name='allego.SpikeSorterClassifierSpec.errorTolerance', index=3,
      number=4, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hiddenLayerFactor', full_name='allego.SpikeSorterClassifierSpec.hiddenLayerFactor', index=4,
      number=5, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='iD', full_name='allego.SpikeSorterClassifierSpec.iD', index=5,
      number=6, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='initBiasStdDev', full_name='allego.SpikeSorterClassifierSpec.initBiasStdDev', index=6,
      number=7, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='initWeightStdDev', full_name='allego.SpikeSorterClassifierSpec.initWeightStdDev', index=7,
      number=8, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='isMasking', full_name='allego.SpikeSorterClassifierSpec.isMasking', index=8,
      number=9, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='l1lambda', full_name='allego.SpikeSorterClassifierSpec.l1lambda', index=9,
      number=10, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='minibatchSize', full_name='allego.SpikeSorterClassifierSpec.minibatchSize', index=10,
      number=11, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='maxNumSamples', full_name='allego.SpikeSorterClassifierSpec.maxNumSamples', index=11,
      number=12, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='numEpochs', full_name='allego.SpikeSorterClassifierSpec.numEpochs', index=12,
      number=13, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='numSamplesTestMSE', full_name='allego.SpikeSorterClassifierSpec.numSamplesTestMSE', index=13,
      number=14, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='numConcurrentModels', full_name='allego.SpikeSorterClassifierSpec.numConcurrentModels', index=14,
      number=15, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='labelNoiseLevel', full_name='allego.SpikeSorterClassifierSpec.labelNoiseLevel', index=15,
      number=16, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3447,
  serialized_end=3828,
)


_SPIKESORTERVARIANTSPEC = _descriptor.Descriptor(
  name='SpikeSorterVariantSpec',
  full_name='allego.SpikeSorterVariantSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='iD', full_name='allego.SpikeSorterVariantSpec.iD', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='siteConfigID', full_name='allego.SpikeSorterVariantSpec.siteConfigID', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='classifierSpec', full_name='allego.SpikeSorterVariantSpec.classifierSpec', index=2,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3830,
  serialized_end=3947,
)


_SPIKESORTERSPEC = _descriptor.Descriptor(
  name='SpikeSorterSpec',
  full_name='allego.SpikeSorterSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='spikeSorterID', full_name='allego.SpikeSorterSpec.spikeSorterID', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='datasourceID', full_name='allego.SpikeSorterSpec.datasourceID', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='biointerfaceID', full_name='allego.SpikeSorterSpec.biointerfaceID', index=2,
      number=3, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='maxNumSiteNeighbors', full_name='allego.SpikeSorterSpec.maxNumSiteNeighbors', index=3,
      number=4, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='neighborRadiusUm', full_name='allego.SpikeSorterSpec.neighborRadiusUm', index=4,
      number=5, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='variant', full_name='allego.SpikeSorterSpec.variant', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='seed', full_name='allego.SpikeSorterSpec.seed', index=6,
      number=8, type=3, cpp_type=2, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3950,
  serialized_end=4154,
)


_SPIKESORTERGETCONFIGREPLY = _descriptor.Descriptor(
  name='SpikeSorterGetConfigReply',
  full_name='allego.SpikeSorterGetConfigReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='spec', full_name='allego.SpikeSorterGetConfigReply.spec', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='aIupdatePeriod', full_name='allego.SpikeSorterGetConfigReply.aIupdatePeriod', index=1,
      number=2, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='orderedVariantIDs', full_name='allego.SpikeSorterGetConfigReply.orderedVariantIDs', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rootVariantID', full_name='allego.SpikeSorterGetConfigReply.rootVariantID', index=3,
      number=4, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sorterStatus', full_name='allego.SpikeSorterGetConfigReply.sorterStatus', index=4,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4157,
  serialized_end=4351,
)


_SPIKESORTERVIZREQUEST = _descriptor.Descriptor(
  name='SpikeSorterVizRequest',
  full_name='allego.SpikeSorterVizRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='spikeSorterID', full_name='allego.SpikeSorterVizRequest.spikeSorterID', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='variantID', full_name='allego.SpikeSorterVizRequest.variantID', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ntvChanIdx', full_name='allego.SpikeSorterVizRequest.ntvChanIdx', index=2,
      number=3, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='spikeLabels', full_name='allego.SpikeSorterVizRequest.spikeLabels', index=3,
      number=4, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='vizType', full_name='allego.SpikeSorterVizRequest.vizType', index=4,
      number=5, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='isYAutoScale', full_name='allego.SpikeSorterVizRequest.isYAutoScale', index=5,
      number=6, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='yLim', full_name='allego.SpikeSorterVizRequest.yLim', index=6,
      number=7, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='figDir', full_name='allego.SpikeSorterVizRequest.figDir', index=7,
      number=8, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='numSpikes', full_name='allego.SpikeSorterVizRequest.numSpikes', index=8,
      number=9, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _SPIKESORTERVIZREQUEST_VTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4354,
  serialized_end=4626,
)


_SPIKESORTERGETDASHBOARDREPLY_PORTSTATSENTRY = _descriptor.Descriptor(
  name='PortStatsEntry',
  full_name='allego.SpikeSorterGetDashboardReply.PortStatsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='allego.SpikeSorterGetDashboardReply.PortStatsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='allego.SpikeSorterGetDashboardReply.PortStatsEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5071,
  serialized_end=5153,
)

_SPIKESORTERGETDASHBOARDREPLY_SITEPANELENTRY = _descriptor.Descriptor(
  name='SitePanelEntry',
  full_name='allego.SpikeSorterGetDashboardReply.SitePanelEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='allego.SpikeSorterGetDashboardReply.SitePanelEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='allego.SpikeSorterGetDashboardReply.SitePanelEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5155,
  serialized_end=5242,
)

_SPIKESORTERGETDASHBOARDREPLY_NEURONPANELENTRY = _descriptor.Descriptor(
  name='NeuronPanelEntry',
  full_name='allego.SpikeSorterGetDashboardReply.NeuronPanelEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='allego.SpikeSorterGetDashboardReply.NeuronPanelEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='allego.SpikeSorterGetDashboardReply.NeuronPanelEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5244,
  serialized_end=5335,
)

_SPIKESORTERGETDASHBOARDREPLY = _descriptor.Descriptor(
  name='SpikeSorterGetDashboardReply',
  full_name='allego.SpikeSorterGetDashboardReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='enabledPorts', full_name='allego.SpikeSorterGetDashboardReply.enabledPorts', index=0,
      number=1, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='general', full_name='allego.SpikeSorterGetDashboardReply.general', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='siteStats', full_name='allego.SpikeSorterGetDashboardReply.siteStats', index=2,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='portStats', full_name='allego.SpikeSorterGetDashboardReply.portStats', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sitePanel', full_name='allego.SpikeSorterGetDashboardReply.sitePanel', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='neuronPanel', full_name='allego.SpikeSorterGetDashboardReply.neuronPanel', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='aI', full_name='allego.SpikeSorterGetDashboardReply.aI', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_SPIKESORTERGETDASHBOARDREPLY_PORTSTATSENTRY, _SPIKESORTERGETDASHBOARDREPLY_SITEPANELENTRY, _SPIKESORTERGETDASHBOARDREPLY_NEURONPANELENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4629,
  serialized_end=5335,
)


_SPIKESORTERDASHBOARDGENERALREC = _descriptor.Descriptor(
  name='SpikeSorterDashboardGeneralRec',
  full_name='allego.SpikeSorterDashboardGeneralRec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='state', full_name='allego.SpikeSorterDashboardGeneralRec.state', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sorterType', full_name='allego.SpikeSorterDashboardGeneralRec.sorterType', index=1,
      number=2, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sorterID', full_name='allego.SpikeSorterDashboardGeneralRec.sorterID', index=2,
      number=3, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='datasourceID', full_name='allego.SpikeSorterDashboardGeneralRec.datasourceID', index=3,
      number=4, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timeRange', full_name='allego.SpikeSorterDashboardGeneralRec.timeRange', index=4,
      number=5, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='numTotalSites', full_name='allego.SpikeSorterDashboardGeneralRec.numTotalSites', index=5,
      number=6, type=3, cpp_type=2, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='numEnabledSites', full_name='allego.SpikeSorterDashboardGeneralRec.numEnabledSites', index=6,
      number=7, type=3, cpp_type=2, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='numActiveSites', full_name='allego.SpikeSorterDashboardGeneralRec.numActiveSites', index=7,
      number=8, type=3, cpp_type=2, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='numNeurons', full_name='allego.SpikeSorterDashboardGeneralRec.numNeurons', index=8,
      number=9, type=3, cpp_type=2, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='probeYield', full_name='allego.SpikeSorterDashboardGeneralRec.probeYield', index=9,
      number=10, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='siteYield', full_name='allego.SpikeSorterDashboardGeneralRec.siteYield', index=10,
      number=11, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='numSpikesProcessed', full_name='allego.SpikeSorterDashboardGeneralRec.numSpikesProcessed', index=11,
      number=12, type=3, cpp_type=2, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='numSpikesLabeled', full_name='allego.SpikeSorterDashboardGeneralRec.numSpikesLabeled', index=12,
      number=13, type=3, cpp_type=2, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sortEfficiency', full_name='allego.SpikeSorterDashboardGeneralRec.sortEfficiency', index=13,
      number=14, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sinkDesc', full_name='allego.SpikeSorterDashboardGeneralRec.sinkDesc', index=14,
      number=15, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5338,
  serialized_end=5766,
)


_SPIKESORTERDASHBOARDAI = _descriptor.Descriptor(
  name='SpikeSorterDashboardAI',
  full_name='allego.SpikeSorterDashboardAI',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='beta', full_name='allego.SpikeSorterDashboardAI.beta', index=0,
      number=1, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='estimatedReaderCompleteSec', full_name='allego.SpikeSorterDashboardAI.estimatedReaderCompleteSec', index=1,
      number=2, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='interSessionDurSec', full_name='allego.SpikeSorterDashboardAI.interSessionDurSec', index=2,
      number=3, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='interSessionStart', full_name='allego.SpikeSorterDashboardAI.interSessionStart', index=3,
      number=4, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sessionDurSec', full_name='allego.SpikeSorterDashboardAI.sessionDurSec', index=4,
      number=5, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sessionStart', full_name='allego.SpikeSorterDashboardAI.sessionStart', index=5,
      number=6, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sessionIdx', full_name='allego.SpikeSorterDashboardAI.sessionIdx', index=6,
      number=7, type=3, cpp_type=2, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='startTime', full_name='allego.SpikeSorterDashboardAI.startTime', index=7,
      number=8, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5769,
  serialized_end=5982,
)


_INDICODASHBOARDSITESTATS = _descriptor.Descriptor(
  name='IndicoDashboardSiteStats',
  full_name='allego.IndicoDashboardSiteStats',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='snr', full_name='allego.IndicoDashboardSiteStats.snr', index=0,
      number=1, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='noise', full_name='allego.IndicoDashboardSiteStats.noise', index=1,
      number=2, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='neuronYield', full_name='allego.IndicoDashboardSiteStats.neuronYield', index=2,
      number=3, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='numNeurons', full_name='allego.IndicoDashboardSiteStats.numNeurons', index=3,
      number=4, type=3, cpp_type=2, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5984,
  serialized_end=6079,
)


_INDICODASHBOARDPORTSTATS = _descriptor.Descriptor(
  name='IndicoDashboardPortStats',
  full_name='allego.IndicoDashboardPortStats',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='snr', full_name='allego.IndicoDashboardPortStats.snr', index=0,
      number=1, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='noise', full_name='allego.IndicoDashboardPortStats.noise', index=1,
      number=2, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='neuronYield', full_name='allego.IndicoDashboardPortStats.neuronYield', index=2,
      number=3, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sortEfficiency', full_name='allego.IndicoDashboardPortStats.sortEfficiency', index=3,
      number=4, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='numEnabledSites', full_name='allego.IndicoDashboardPortStats.numEnabledSites', index=4,
      number=5, type=3, cpp_type=2, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='numNeurons', full_name='allego.IndicoDashboardPortStats.numNeurons', index=5,
      number=6, type=3, cpp_type=2, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6082,
  serialized_end=6226,
)


_INDICODASHBOARDSITEINDICATORS = _descriptor.Descriptor(
  name='IndicoDashboardSiteIndicators',
  full_name='allego.IndicoDashboardSiteIndicators',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ntvChanIdx', full_name='allego.IndicoDashboardSiteIndicators.ntvChanIdx', index=0,
      number=1, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='snr', full_name='allego.IndicoDashboardSiteIndicators.snr', index=1,
      number=2, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='noise', full_name='allego.IndicoDashboardSiteIndicators.noise', index=2,
      number=3, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='neuronYield', full_name='allego.IndicoDashboardSiteIndicators.neuronYield', index=3,
      number=4, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sortEfficiency', full_name='allego.IndicoDashboardSiteIndicators.sortEfficiency', index=4,
      number=5, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='spikeRate', full_name='allego.IndicoDashboardSiteIndicators.spikeRate', index=5,
      number=6, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='posProbeX', full_name='allego.IndicoDashboardSiteIndicators.posProbeX', index=6,
      number=7, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='posProbeY', full_name='allego.IndicoDashboardSiteIndicators.posProbeY', index=7,
      number=8, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='posProbeZ', full_name='allego.IndicoDashboardSiteIndicators.posProbeZ', index=8,
      number=9, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='siteNum', full_name='allego.IndicoDashboardSiteIndicators.siteNum', index=9,
      number=10, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6229,
  serialized_end=6446,
)


_INDICODASHBOARDNEURONINDICATORS = _descriptor.Descriptor(
  name='IndicoDashboardNeuronIndicators',
  full_name='allego.IndicoDashboardNeuronIndicators',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='neuronID', full_name='allego.IndicoDashboardNeuronIndicators.neuronID', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='snr', full_name='allego.IndicoDashboardNeuronIndicators.snr', index=1,
      number=2, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='spikeRate', full_name='allego.IndicoDashboardNeuronIndicators.spikeRate', index=2,
      number=3, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='posProbeX', full_name='allego.IndicoDashboardNeuronIndicators.posProbeX', index=3,
      number=4, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='posProbeY', full_name='allego.IndicoDashboardNeuronIndicators.posProbeY', index=4,
      number=5, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='posProbeZ', full_name='allego.IndicoDashboardNeuronIndicators.posProbeZ', index=5,
      number=6, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='siteNum', full_name='allego.IndicoDashboardNeuronIndicators.siteNum', index=6,
      number=7, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='spikeLabel', full_name='allego.IndicoDashboardNeuronIndicators.spikeLabel', index=7,
      number=8, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6449,
  serialized_end=6626,
)


_SPIKESORTERDASHBOARDSITEDESC = _descriptor.Descriptor(
  name='SpikeSorterDashboardSiteDesc',
  full_name='allego.SpikeSorterDashboardSiteDesc',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='port', full_name='allego.SpikeSorterDashboardSiteDesc.port', index=0,
      number=1, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ntvChanIdx', full_name='allego.SpikeSorterDashboardSiteDesc.ntvChanIdx', index=1,
      number=2, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='posProbe', full_name='allego.SpikeSorterDashboardSiteDesc.posProbe', index=2,
      number=3, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='posBrain', full_name='allego.SpikeSorterDashboardSiteDesc.posBrain', index=3,
      number=4, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='snrMax', full_name='allego.SpikeSorterDashboardSiteDesc.snrMax', index=4,
      number=5, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='snrMin', full_name='allego.SpikeSorterDashboardSiteDesc.snrMin', index=5,
      number=6, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='noiseLevel', full_name='allego.SpikeSorterDashboardSiteDesc.noiseLevel', index=6,
      number=7, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='numNeurons', full_name='allego.SpikeSorterDashboardSiteDesc.numNeurons', index=7,
      number=8, type=3, cpp_type=2, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='indicoCluster', full_name='allego.SpikeSorterDashboardSiteDesc.indicoCluster', index=8,
      number=10, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pileWaveformMinValue', full_name='allego.SpikeSorterDashboardSiteDesc.pileWaveformMinValue', index=9,
      number=13, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pileWaveformMaxValue', full_name='allego.SpikeSorterDashboardSiteDesc.pileWaveformMaxValue', index=10,
      number=14, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6629,
  serialized_end=6924,
)


_SPIKESORTERDASHBOARDNEURONDESC = _descriptor.Descriptor(
  name='SpikeSorterDashboardNeuronDesc',
  full_name='allego.SpikeSorterDashboardNeuronDesc',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='port', full_name='allego.SpikeSorterDashboardNeuronDesc.port', index=0,
      number=1, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='desc', full_name='allego.SpikeSorterDashboardNeuronDesc.desc', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='snr', full_name='allego.SpikeSorterDashboardNeuronDesc.snr', index=2,
      number=5, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='IsihMax', full_name='allego.SpikeSorterDashboardNeuronDesc.IsihMax', index=3,
      number=6, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='IsihArgmaxSec', full_name='allego.SpikeSorterDashboardNeuronDesc.IsihArgmaxSec', index=4,
      number=7, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='IsihArgmaxIdx', full_name='allego.SpikeSorterDashboardNeuronDesc.IsihArgmaxIdx', index=5,
      number=8, type=3, cpp_type=2, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='IsihMean', full_name='allego.SpikeSorterDashboardNeuronDesc.IsihMean', index=6,
      number=9, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='IsihSd', full_name='allego.SpikeSorterDashboardNeuronDesc.IsihSd', index=7,
      number=10, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6927,
  serialized_end=7137,
)


_SPIKESORTERDASHBOARDNEURONDETAIL = _descriptor.Descriptor(
  name='SpikeSorterDashboardNeuronDetail',
  full_name='allego.SpikeSorterDashboardNeuronDetail',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='desc', full_name='allego.SpikeSorterDashboardNeuronDetail.desc', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='templateWaveform', full_name='allego.SpikeSorterDashboardNeuronDetail.templateWaveform', index=1,
      number=2, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='templateSdWaveform', full_name='allego.SpikeSorterDashboardNeuronDetail.templateSdWaveform', index=2,
      number=3, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pileWaveformData', full_name='allego.SpikeSorterDashboardNeuronDetail.pileWaveformData', index=3,
      number=4, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='numSamplesPileWaveform', full_name='allego.SpikeSorterDashboardNeuronDetail.numSamplesPileWaveform', index=4,
      number=5, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='numPileWaveforms', full_name='allego.SpikeSorterDashboardNeuronDetail.numPileWaveforms', index=5,
      number=6, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='isih', full_name='allego.SpikeSorterDashboardNeuronDetail.isih', index=6,
      number=11, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7140,
  serialized_end=7390,
)


_SPIKESORTERDASHBOARDSITEDETAIL = _descriptor.Descriptor(
  name='SpikeSorterDashboardSiteDetail',
  full_name='allego.SpikeSorterDashboardSiteDetail',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='desc', full_name='allego.SpikeSorterDashboardSiteDetail.desc', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='orderedSpikeLabel', full_name='allego.SpikeSorterDashboardSiteDetail.orderedSpikeLabel', index=1,
      number=2, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='neuron', full_name='allego.SpikeSorterDashboardSiteDetail.neuron', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7393,
  serialized_end=7562,
)

_SPIKESORTERLAUNCHREQUEST.fields_by_name['source'].message_type = common__pb2._FILEDESCRIPTOR
_SPIKESORTERLAUNCHREQUEST.fields_by_name['variant'].message_type = _SPIKESORTERVARIANTSPEC
_SPIKESORTERLAUNCHREQUEST.fields_by_name['mode'].enum_type = _SPIKESORTERMODE
_SPIKESORTERCOMMANDREQUEST.fields_by_name['cmd'].enum_type = _SPIKESORTERCOMMAND
_SPIKESORTERCOMMANDREQUEST.fields_by_name['subCmd'].enum_type = _SPIKESORTERSUBCOMMAND
_SPIKESORTERSTATE.fields_by_name['sys'].enum_type = _SPIKESORTERSTATESYSTEM
_SPKSORTIOREQ.fields_by_name['type'].enum_type = _SPKSORTIOTYPE
_SPKSORTIOREQ.fields_by_name['target'].enum_type = _SPKSORTIOTARGET
_SPKSORTIOREQ.fields_by_name['mode'].enum_type = _SPKSORTIOMODE
_SPIKESORTERLAUNCHREPLY.fields_by_name['sorterType'].enum_type = _SPIKESORTERTYPE
_SPIKESORTERRASTERDATAREPLY.fields_by_name['spikeTimestampsByChannel'].message_type = biointerface__pb2._SPIKETIMESTAMPDATA
_SPIKESORTERDYNAMIC_CRITERIA.fields_by_name['detect'].enum_type = _SPIKESORTERCRITERIONLEVEL
_SPIKESORTERDYNAMIC_CRITERIA.fields_by_name['train'].enum_type = _SPIKESORTERCRITERIONLEVEL
_SPIKESORTERDYNAMIC_CRITERIA.fields_by_name['sort'].enum_type = _SPIKESORTERCRITERIONLEVEL
_SPIKESORTERDYNAMIC_CRITERIA.containing_type = _SPIKESORTERDYNAMIC
_SPIKESORTERDYNAMIC_UPDATEPERIODSEC.containing_type = _SPIKESORTERDYNAMIC
_SPIKESORTERDYNAMIC.fields_by_name['updatePeriodSec'].message_type = _SPIKESORTERDYNAMIC_UPDATEPERIODSEC
_SPIKESORTERDYNAMIC.fields_by_name['criteria'].message_type = _SPIKESORTERDYNAMIC_CRITERIA
_SPIKESORTERSETDYNAMICREQUEST_VARIANTENTRY.fields_by_name['value'].message_type = _SPIKESORTERDYNAMIC
_SPIKESORTERSETDYNAMICREQUEST_VARIANTENTRY.containing_type = _SPIKESORTERSETDYNAMICREQUEST
_SPIKESORTERSETDYNAMICREQUEST.fields_by_name['variant'].message_type = _SPIKESORTERSETDYNAMICREQUEST_VARIANTENTRY
_SPIKESORTERGETDYNAMICREPLY_VARIANTENTRY.fields_by_name['value'].message_type = _SPIKESORTERDYNAMIC
_SPIKESORTERGETDYNAMICREPLY_VARIANTENTRY.containing_type = _SPIKESORTERGETDYNAMICREPLY
_SPIKESORTERGETDYNAMICREPLY.fields_by_name['variant'].message_type = _SPIKESORTERGETDYNAMICREPLY_VARIANTENTRY
_GETSPIKESORTERPARAMCOMMANDREPLY.fields_by_name['rec'].message_type = common__pb2._SPIKESORTERPARAMCOMMANDRECORD
_CLUSTERMAPRECORD.fields_by_name['stats'].message_type = _CLUSTERMAPSTATS
_SPIKESORTSITESTATUS.fields_by_name['cluster'].message_type = _CLUSTERMAPRECORD
_SPIKESORTERSTATUSREPLY.fields_by_name['state'].message_type = _SPIKESORTERSTATE
_SPIKESORTERSTATUSREPLY.fields_by_name['phase'].message_type = _SPIKESORTPHASESTATUS
_SPIKESORTERSTATUSREPLY.fields_by_name['enabledSite'].message_type = _SPIKESORTSITESTATUS
_SPIKESORTERSTATUSVARIANTSREPLY.fields_by_name['variants'].message_type = _SPIKESORTERSTATUSREPLY
_SPIKESORTERVARIANTSPEC.fields_by_name['classifierSpec'].message_type = _SPIKESORTERCLASSIFIERSPEC
_SPIKESORTERSPEC.fields_by_name['variant'].message_type = _SPIKESORTERVARIANTSPEC
_SPIKESORTERGETCONFIGREPLY.fields_by_name['spec'].message_type = _SPIKESORTERSPEC
_SPIKESORTERGETCONFIGREPLY.fields_by_name['sorterStatus'].message_type = _SPIKESORTERSTATUSREPLY
_SPIKESORTERVIZREQUEST.fields_by_name['vizType'].enum_type = _SPIKESORTERVIZREQUEST_VTYPE
_SPIKESORTERVIZREQUEST_VTYPE.containing_type = _SPIKESORTERVIZREQUEST
_SPIKESORTERGETDASHBOARDREPLY_PORTSTATSENTRY.fields_by_name['value'].message_type = _INDICODASHBOARDPORTSTATS
_SPIKESORTERGETDASHBOARDREPLY_PORTSTATSENTRY.containing_type = _SPIKESORTERGETDASHBOARDREPLY
_SPIKESORTERGETDASHBOARDREPLY_SITEPANELENTRY.fields_by_name['value'].message_type = _INDICODASHBOARDSITEINDICATORS
_SPIKESORTERGETDASHBOARDREPLY_SITEPANELENTRY.containing_type = _SPIKESORTERGETDASHBOARDREPLY
_SPIKESORTERGETDASHBOARDREPLY_NEURONPANELENTRY.fields_by_name['value'].message_type = _INDICODASHBOARDNEURONINDICATORS
_SPIKESORTERGETDASHBOARDREPLY_NEURONPANELENTRY.containing_type = _SPIKESORTERGETDASHBOARDREPLY
_SPIKESORTERGETDASHBOARDREPLY.fields_by_name['enabledPorts'].enum_type = common__pb2._PORT
_SPIKESORTERGETDASHBOARDREPLY.fields_by_name['general'].message_type = _SPIKESORTERDASHBOARDGENERALREC
_SPIKESORTERGETDASHBOARDREPLY.fields_by_name['siteStats'].message_type = _INDICODASHBOARDSITESTATS
_SPIKESORTERGETDASHBOARDREPLY.fields_by_name['portStats'].message_type = _SPIKESORTERGETDASHBOARDREPLY_PORTSTATSENTRY
_SPIKESORTERGETDASHBOARDREPLY.fields_by_name['sitePanel'].message_type = _SPIKESORTERGETDASHBOARDREPLY_SITEPANELENTRY
_SPIKESORTERGETDASHBOARDREPLY.fields_by_name['neuronPanel'].message_type = _SPIKESORTERGETDASHBOARDREPLY_NEURONPANELENTRY
_SPIKESORTERGETDASHBOARDREPLY.fields_by_name['aI'].message_type = _SPIKESORTERDASHBOARDAI
_SPIKESORTERDASHBOARDGENERALREC.fields_by_name['state'].message_type = _SPIKESORTERSTATE
_SPIKESORTERDASHBOARDGENERALREC.fields_by_name['sorterType'].enum_type = _SPIKESORTERTYPE
_SPIKESORTERDASHBOARDGENERALREC.fields_by_name['sinkDesc'].message_type = common__pb2._FILEDESCRIPTOR
_SPIKESORTERDASHBOARDSITEDESC.fields_by_name['port'].enum_type = common__pb2._PORT
_SPIKESORTERDASHBOARDSITEDESC.fields_by_name['indicoCluster'].message_type = _CLUSTERMAPRECORD
_SPIKESORTERDASHBOARDNEURONDESC.fields_by_name['port'].enum_type = common__pb2._PORT
_SPIKESORTERDASHBOARDNEURONDESC.fields_by_name['desc'].message_type = biointerface__pb2._NEURONDESCRIPTOR
_SPIKESORTERDASHBOARDNEURONDETAIL.fields_by_name['desc'].message_type = biointerface__pb2._NEURONDESCRIPTOR
_SPIKESORTERDASHBOARDNEURONDETAIL.fields_by_name['isih'].message_type = biointerface__pb2._NEURONHISTDATA
_SPIKESORTERDASHBOARDSITEDETAIL.fields_by_name['desc'].message_type = _SPIKESORTERDASHBOARDSITEDESC
_SPIKESORTERDASHBOARDSITEDETAIL.fields_by_name['neuron'].message_type = _SPIKESORTERDASHBOARDNEURONDETAIL
DESCRIPTOR.message_types_by_name['SpikeSorterLaunchRequest'] = _SPIKESORTERLAUNCHREQUEST
DESCRIPTOR.message_types_by_name['SpikeSorterCommandRequest'] = _SPIKESORTERCOMMANDREQUEST
DESCRIPTOR.message_types_by_name['SpikeSorterState'] = _SPIKESORTERSTATE
DESCRIPTOR.message_types_by_name['SpkSortIOreq'] = _SPKSORTIOREQ
DESCRIPTOR.message_types_by_name['SpikeSorterLaunchReply'] = _SPIKESORTERLAUNCHREPLY
DESCRIPTOR.message_types_by_name['GetSpikeSorterIDsReply'] = _GETSPIKESORTERIDSREPLY
DESCRIPTOR.message_types_by_name['SpikeSorterGetRasterDataRequest'] = _SPIKESORTERGETRASTERDATAREQUEST
DESCRIPTOR.message_types_by_name['SpikeSorterRasterDataReply'] = _SPIKESORTERRASTERDATAREPLY
DESCRIPTOR.message_types_by_name['SpikeSorterStandardRequest'] = _SPIKESORTERSTANDARDREQUEST
DESCRIPTOR.message_types_by_name['SpikeSorterDynamic'] = _SPIKESORTERDYNAMIC
DESCRIPTOR.message_types_by_name['SpikeSorterSetDynamicRequest'] = _SPIKESORTERSETDYNAMICREQUEST
DESCRIPTOR.message_types_by_name['SpikeSorterGetDynamicReply'] = _SPIKESORTERGETDYNAMICREPLY
DESCRIPTOR.message_types_by_name['GetSpikeSorterParamCommandReply'] = _GETSPIKESORTERPARAMCOMMANDREPLY
DESCRIPTOR.message_types_by_name['ClusterMapOutliers'] = _CLUSTERMAPOUTLIERS
DESCRIPTOR.message_types_by_name['ClusterMapQuartiles'] = _CLUSTERMAPQUARTILES
DESCRIPTOR.message_types_by_name['ClusterMapStats'] = _CLUSTERMAPSTATS
DESCRIPTOR.message_types_by_name['ClusterMapRecord'] = _CLUSTERMAPRECORD
DESCRIPTOR.message_types_by_name['SpikeSortSiteStatus'] = _SPIKESORTSITESTATUS
DESCRIPTOR.message_types_by_name['SpikeSortPhaseStatus'] = _SPIKESORTPHASESTATUS
DESCRIPTOR.message_types_by_name['SpikeSortNbrIdxList'] = _SPIKESORTNBRIDXLIST
DESCRIPTOR.message_types_by_name['SpikeSorterStatusReply'] = _SPIKESORTERSTATUSREPLY
DESCRIPTOR.message_types_by_name['SpikeSorterStatusVariantsReply'] = _SPIKESORTERSTATUSVARIANTSREPLY
DESCRIPTOR.message_types_by_name['SpikeSorterClassifierSpec'] = _SPIKESORTERCLASSIFIERSPEC
DESCRIPTOR.message_types_by_name['SpikeSorterVariantSpec'] = _SPIKESORTERVARIANTSPEC
DESCRIPTOR.message_types_by_name['SpikeSorterSpec'] = _SPIKESORTERSPEC
DESCRIPTOR.message_types_by_name['SpikeSorterGetConfigReply'] = _SPIKESORTERGETCONFIGREPLY
DESCRIPTOR.message_types_by_name['SpikeSorterVizRequest'] = _SPIKESORTERVIZREQUEST
DESCRIPTOR.message_types_by_name['SpikeSorterGetDashboardReply'] = _SPIKESORTERGETDASHBOARDREPLY
DESCRIPTOR.message_types_by_name['SpikeSorterDashboardGeneralRec'] = _SPIKESORTERDASHBOARDGENERALREC
DESCRIPTOR.message_types_by_name['SpikeSorterDashboardAI'] = _SPIKESORTERDASHBOARDAI
DESCRIPTOR.message_types_by_name['IndicoDashboardSiteStats'] = _INDICODASHBOARDSITESTATS
DESCRIPTOR.message_types_by_name['IndicoDashboardPortStats'] = _INDICODASHBOARDPORTSTATS
DESCRIPTOR.message_types_by_name['IndicoDashboardSiteIndicators'] = _INDICODASHBOARDSITEINDICATORS
DESCRIPTOR.message_types_by_name['IndicoDashboardNeuronIndicators'] = _INDICODASHBOARDNEURONINDICATORS
DESCRIPTOR.message_types_by_name['SpikeSorterDashboardSiteDesc'] = _SPIKESORTERDASHBOARDSITEDESC
DESCRIPTOR.message_types_by_name['SpikeSorterDashboardNeuronDesc'] = _SPIKESORTERDASHBOARDNEURONDESC
DESCRIPTOR.message_types_by_name['SpikeSorterDashboardNeuronDetail'] = _SPIKESORTERDASHBOARDNEURONDETAIL
DESCRIPTOR.message_types_by_name['SpikeSorterDashboardSiteDetail'] = _SPIKESORTERDASHBOARDSITEDETAIL
DESCRIPTOR.enum_types_by_name['SpikeSorterType'] = _SPIKESORTERTYPE
DESCRIPTOR.enum_types_by_name['SpikeSorterCommand'] = _SPIKESORTERCOMMAND
DESCRIPTOR.enum_types_by_name['SpikeSorterSubCommand'] = _SPIKESORTERSUBCOMMAND
DESCRIPTOR.enum_types_by_name['SpikeSorterMode'] = _SPIKESORTERMODE
DESCRIPTOR.enum_types_by_name['SpikeSorterStateSystem'] = _SPIKESORTERSTATESYSTEM
DESCRIPTOR.enum_types_by_name['SpkSortIOtype'] = _SPKSORTIOTYPE
DESCRIPTOR.enum_types_by_name['SpkSortIOtarget'] = _SPKSORTIOTARGET
DESCRIPTOR.enum_types_by_name['SpkSortIOmode'] = _SPKSORTIOMODE
DESCRIPTOR.enum_types_by_name['SpikeSorterCriterionLevel'] = _SPIKESORTERCRITERIONLEVEL
DESCRIPTOR.enum_types_by_name['SS_STAT'] = _SS_STAT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SpikeSorterLaunchRequest = _reflection.GeneratedProtocolMessageType('SpikeSorterLaunchRequest', (_message.Message,), {
  'DESCRIPTOR' : _SPIKESORTERLAUNCHREQUEST,
  '__module__' : 'spikesorter_pb2'
  # @@protoc_insertion_point(class_scope:allego.SpikeSorterLaunchRequest)
  })
_sym_db.RegisterMessage(SpikeSorterLaunchRequest)

SpikeSorterCommandRequest = _reflection.GeneratedProtocolMessageType('SpikeSorterCommandRequest', (_message.Message,), {
  'DESCRIPTOR' : _SPIKESORTERCOMMANDREQUEST,
  '__module__' : 'spikesorter_pb2'
  # @@protoc_insertion_point(class_scope:allego.SpikeSorterCommandRequest)
  })
_sym_db.RegisterMessage(SpikeSorterCommandRequest)

SpikeSorterState = _reflection.GeneratedProtocolMessageType('SpikeSorterState', (_message.Message,), {
  'DESCRIPTOR' : _SPIKESORTERSTATE,
  '__module__' : 'spikesorter_pb2'
  # @@protoc_insertion_point(class_scope:allego.SpikeSorterState)
  })
_sym_db.RegisterMessage(SpikeSorterState)

SpkSortIOreq = _reflection.GeneratedProtocolMessageType('SpkSortIOreq', (_message.Message,), {
  'DESCRIPTOR' : _SPKSORTIOREQ,
  '__module__' : 'spikesorter_pb2'
  # @@protoc_insertion_point(class_scope:allego.SpkSortIOreq)
  })
_sym_db.RegisterMessage(SpkSortIOreq)

SpikeSorterLaunchReply = _reflection.GeneratedProtocolMessageType('SpikeSorterLaunchReply', (_message.Message,), {
  'DESCRIPTOR' : _SPIKESORTERLAUNCHREPLY,
  '__module__' : 'spikesorter_pb2'
  # @@protoc_insertion_point(class_scope:allego.SpikeSorterLaunchReply)
  })
_sym_db.RegisterMessage(SpikeSorterLaunchReply)

GetSpikeSorterIDsReply = _reflection.GeneratedProtocolMessageType('GetSpikeSorterIDsReply', (_message.Message,), {
  'DESCRIPTOR' : _GETSPIKESORTERIDSREPLY,
  '__module__' : 'spikesorter_pb2'
  # @@protoc_insertion_point(class_scope:allego.GetSpikeSorterIDsReply)
  })
_sym_db.RegisterMessage(GetSpikeSorterIDsReply)

SpikeSorterGetRasterDataRequest = _reflection.GeneratedProtocolMessageType('SpikeSorterGetRasterDataRequest', (_message.Message,), {
  'DESCRIPTOR' : _SPIKESORTERGETRASTERDATAREQUEST,
  '__module__' : 'spikesorter_pb2'
  # @@protoc_insertion_point(class_scope:allego.SpikeSorterGetRasterDataRequest)
  })
_sym_db.RegisterMessage(SpikeSorterGetRasterDataRequest)

SpikeSorterRasterDataReply = _reflection.GeneratedProtocolMessageType('SpikeSorterRasterDataReply', (_message.Message,), {
  'DESCRIPTOR' : _SPIKESORTERRASTERDATAREPLY,
  '__module__' : 'spikesorter_pb2'
  # @@protoc_insertion_point(class_scope:allego.SpikeSorterRasterDataReply)
  })
_sym_db.RegisterMessage(SpikeSorterRasterDataReply)

SpikeSorterStandardRequest = _reflection.GeneratedProtocolMessageType('SpikeSorterStandardRequest', (_message.Message,), {
  'DESCRIPTOR' : _SPIKESORTERSTANDARDREQUEST,
  '__module__' : 'spikesorter_pb2'
  # @@protoc_insertion_point(class_scope:allego.SpikeSorterStandardRequest)
  })
_sym_db.RegisterMessage(SpikeSorterStandardRequest)

SpikeSorterDynamic = _reflection.GeneratedProtocolMessageType('SpikeSorterDynamic', (_message.Message,), {

  'Criteria' : _reflection.GeneratedProtocolMessageType('Criteria', (_message.Message,), {
    'DESCRIPTOR' : _SPIKESORTERDYNAMIC_CRITERIA,
    '__module__' : 'spikesorter_pb2'
    # @@protoc_insertion_point(class_scope:allego.SpikeSorterDynamic.Criteria)
    })
  ,

  'UpdatePeriodSec' : _reflection.GeneratedProtocolMessageType('UpdatePeriodSec', (_message.Message,), {
    'DESCRIPTOR' : _SPIKESORTERDYNAMIC_UPDATEPERIODSEC,
    '__module__' : 'spikesorter_pb2'
    # @@protoc_insertion_point(class_scope:allego.SpikeSorterDynamic.UpdatePeriodSec)
    })
  ,
  'DESCRIPTOR' : _SPIKESORTERDYNAMIC,
  '__module__' : 'spikesorter_pb2'
  # @@protoc_insertion_point(class_scope:allego.SpikeSorterDynamic)
  })
_sym_db.RegisterMessage(SpikeSorterDynamic)
_sym_db.RegisterMessage(SpikeSorterDynamic.Criteria)
_sym_db.RegisterMessage(SpikeSorterDynamic.UpdatePeriodSec)

SpikeSorterSetDynamicRequest = _reflection.GeneratedProtocolMessageType('SpikeSorterSetDynamicRequest', (_message.Message,), {

  'VariantEntry' : _reflection.GeneratedProtocolMessageType('VariantEntry', (_message.Message,), {
    'DESCRIPTOR' : _SPIKESORTERSETDYNAMICREQUEST_VARIANTENTRY,
    '__module__' : 'spikesorter_pb2'
    # @@protoc_insertion_point(class_scope:allego.SpikeSorterSetDynamicRequest.VariantEntry)
    })
  ,
  'DESCRIPTOR' : _SPIKESORTERSETDYNAMICREQUEST,
  '__module__' : 'spikesorter_pb2'
  # @@protoc_insertion_point(class_scope:allego.SpikeSorterSetDynamicRequest)
  })
_sym_db.RegisterMessage(SpikeSorterSetDynamicRequest)
_sym_db.RegisterMessage(SpikeSorterSetDynamicRequest.VariantEntry)

SpikeSorterGetDynamicReply = _reflection.GeneratedProtocolMessageType('SpikeSorterGetDynamicReply', (_message.Message,), {

  'VariantEntry' : _reflection.GeneratedProtocolMessageType('VariantEntry', (_message.Message,), {
    'DESCRIPTOR' : _SPIKESORTERGETDYNAMICREPLY_VARIANTENTRY,
    '__module__' : 'spikesorter_pb2'
    # @@protoc_insertion_point(class_scope:allego.SpikeSorterGetDynamicReply.VariantEntry)
    })
  ,
  'DESCRIPTOR' : _SPIKESORTERGETDYNAMICREPLY,
  '__module__' : 'spikesorter_pb2'
  # @@protoc_insertion_point(class_scope:allego.SpikeSorterGetDynamicReply)
  })
_sym_db.RegisterMessage(SpikeSorterGetDynamicReply)
_sym_db.RegisterMessage(SpikeSorterGetDynamicReply.VariantEntry)

GetSpikeSorterParamCommandReply = _reflection.GeneratedProtocolMessageType('GetSpikeSorterParamCommandReply', (_message.Message,), {
  'DESCRIPTOR' : _GETSPIKESORTERPARAMCOMMANDREPLY,
  '__module__' : 'spikesorter_pb2'
  # @@protoc_insertion_point(class_scope:allego.GetSpikeSorterParamCommandReply)
  })
_sym_db.RegisterMessage(GetSpikeSorterParamCommandReply)

ClusterMapOutliers = _reflection.GeneratedProtocolMessageType('ClusterMapOutliers', (_message.Message,), {
  'DESCRIPTOR' : _CLUSTERMAPOUTLIERS,
  '__module__' : 'spikesorter_pb2'
  # @@protoc_insertion_point(class_scope:allego.ClusterMapOutliers)
  })
_sym_db.RegisterMessage(ClusterMapOutliers)

ClusterMapQuartiles = _reflection.GeneratedProtocolMessageType('ClusterMapQuartiles', (_message.Message,), {
  'DESCRIPTOR' : _CLUSTERMAPQUARTILES,
  '__module__' : 'spikesorter_pb2'
  # @@protoc_insertion_point(class_scope:allego.ClusterMapQuartiles)
  })
_sym_db.RegisterMessage(ClusterMapQuartiles)

ClusterMapStats = _reflection.GeneratedProtocolMessageType('ClusterMapStats', (_message.Message,), {
  'DESCRIPTOR' : _CLUSTERMAPSTATS,
  '__module__' : 'spikesorter_pb2'
  # @@protoc_insertion_point(class_scope:allego.ClusterMapStats)
  })
_sym_db.RegisterMessage(ClusterMapStats)

ClusterMapRecord = _reflection.GeneratedProtocolMessageType('ClusterMapRecord', (_message.Message,), {
  'DESCRIPTOR' : _CLUSTERMAPRECORD,
  '__module__' : 'spikesorter_pb2'
  # @@protoc_insertion_point(class_scope:allego.ClusterMapRecord)
  })
_sym_db.RegisterMessage(ClusterMapRecord)

SpikeSortSiteStatus = _reflection.GeneratedProtocolMessageType('SpikeSortSiteStatus', (_message.Message,), {
  'DESCRIPTOR' : _SPIKESORTSITESTATUS,
  '__module__' : 'spikesorter_pb2'
  # @@protoc_insertion_point(class_scope:allego.SpikeSortSiteStatus)
  })
_sym_db.RegisterMessage(SpikeSortSiteStatus)

SpikeSortPhaseStatus = _reflection.GeneratedProtocolMessageType('SpikeSortPhaseStatus', (_message.Message,), {
  'DESCRIPTOR' : _SPIKESORTPHASESTATUS,
  '__module__' : 'spikesorter_pb2'
  # @@protoc_insertion_point(class_scope:allego.SpikeSortPhaseStatus)
  })
_sym_db.RegisterMessage(SpikeSortPhaseStatus)

SpikeSortNbrIdxList = _reflection.GeneratedProtocolMessageType('SpikeSortNbrIdxList', (_message.Message,), {
  'DESCRIPTOR' : _SPIKESORTNBRIDXLIST,
  '__module__' : 'spikesorter_pb2'
  # @@protoc_insertion_point(class_scope:allego.SpikeSortNbrIdxList)
  })
_sym_db.RegisterMessage(SpikeSortNbrIdxList)

SpikeSorterStatusReply = _reflection.GeneratedProtocolMessageType('SpikeSorterStatusReply', (_message.Message,), {
  'DESCRIPTOR' : _SPIKESORTERSTATUSREPLY,
  '__module__' : 'spikesorter_pb2'
  # @@protoc_insertion_point(class_scope:allego.SpikeSorterStatusReply)
  })
_sym_db.RegisterMessage(SpikeSorterStatusReply)

SpikeSorterStatusVariantsReply = _reflection.GeneratedProtocolMessageType('SpikeSorterStatusVariantsReply', (_message.Message,), {
  'DESCRIPTOR' : _SPIKESORTERSTATUSVARIANTSREPLY,
  '__module__' : 'spikesorter_pb2'
  # @@protoc_insertion_point(class_scope:allego.SpikeSorterStatusVariantsReply)
  })
_sym_db.RegisterMessage(SpikeSorterStatusVariantsReply)

SpikeSorterClassifierSpec = _reflection.GeneratedProtocolMessageType('SpikeSorterClassifierSpec', (_message.Message,), {
  'DESCRIPTOR' : _SPIKESORTERCLASSIFIERSPEC,
  '__module__' : 'spikesorter_pb2'
  # @@protoc_insertion_point(class_scope:allego.SpikeSorterClassifierSpec)
  })
_sym_db.RegisterMessage(SpikeSorterClassifierSpec)

SpikeSorterVariantSpec = _reflection.GeneratedProtocolMessageType('SpikeSorterVariantSpec', (_message.Message,), {
  'DESCRIPTOR' : _SPIKESORTERVARIANTSPEC,
  '__module__' : 'spikesorter_pb2'
  # @@protoc_insertion_point(class_scope:allego.SpikeSorterVariantSpec)
  })
_sym_db.RegisterMessage(SpikeSorterVariantSpec)

SpikeSorterSpec = _reflection.GeneratedProtocolMessageType('SpikeSorterSpec', (_message.Message,), {
  'DESCRIPTOR' : _SPIKESORTERSPEC,
  '__module__' : 'spikesorter_pb2'
  # @@protoc_insertion_point(class_scope:allego.SpikeSorterSpec)
  })
_sym_db.RegisterMessage(SpikeSorterSpec)

SpikeSorterGetConfigReply = _reflection.GeneratedProtocolMessageType('SpikeSorterGetConfigReply', (_message.Message,), {
  'DESCRIPTOR' : _SPIKESORTERGETCONFIGREPLY,
  '__module__' : 'spikesorter_pb2'
  # @@protoc_insertion_point(class_scope:allego.SpikeSorterGetConfigReply)
  })
_sym_db.RegisterMessage(SpikeSorterGetConfigReply)

SpikeSorterVizRequest = _reflection.GeneratedProtocolMessageType('SpikeSorterVizRequest', (_message.Message,), {
  'DESCRIPTOR' : _SPIKESORTERVIZREQUEST,
  '__module__' : 'spikesorter_pb2'
  # @@protoc_insertion_point(class_scope:allego.SpikeSorterVizRequest)
  })
_sym_db.RegisterMessage(SpikeSorterVizRequest)

SpikeSorterGetDashboardReply = _reflection.GeneratedProtocolMessageType('SpikeSorterGetDashboardReply', (_message.Message,), {

  'PortStatsEntry' : _reflection.GeneratedProtocolMessageType('PortStatsEntry', (_message.Message,), {
    'DESCRIPTOR' : _SPIKESORTERGETDASHBOARDREPLY_PORTSTATSENTRY,
    '__module__' : 'spikesorter_pb2'
    # @@protoc_insertion_point(class_scope:allego.SpikeSorterGetDashboardReply.PortStatsEntry)
    })
  ,

  'SitePanelEntry' : _reflection.GeneratedProtocolMessageType('SitePanelEntry', (_message.Message,), {
    'DESCRIPTOR' : _SPIKESORTERGETDASHBOARDREPLY_SITEPANELENTRY,
    '__module__' : 'spikesorter_pb2'
    # @@protoc_insertion_point(class_scope:allego.SpikeSorterGetDashboardReply.SitePanelEntry)
    })
  ,

  'NeuronPanelEntry' : _reflection.GeneratedProtocolMessageType('NeuronPanelEntry', (_message.Message,), {
    'DESCRIPTOR' : _SPIKESORTERGETDASHBOARDREPLY_NEURONPANELENTRY,
    '__module__' : 'spikesorter_pb2'
    # @@protoc_insertion_point(class_scope:allego.SpikeSorterGetDashboardReply.NeuronPanelEntry)
    })
  ,
  'DESCRIPTOR' : _SPIKESORTERGETDASHBOARDREPLY,
  '__module__' : 'spikesorter_pb2'
  # @@protoc_insertion_point(class_scope:allego.SpikeSorterGetDashboardReply)
  })
_sym_db.RegisterMessage(SpikeSorterGetDashboardReply)
_sym_db.RegisterMessage(SpikeSorterGetDashboardReply.PortStatsEntry)
_sym_db.RegisterMessage(SpikeSorterGetDashboardReply.SitePanelEntry)
_sym_db.RegisterMessage(SpikeSorterGetDashboardReply.NeuronPanelEntry)

SpikeSorterDashboardGeneralRec = _reflection.GeneratedProtocolMessageType('SpikeSorterDashboardGeneralRec', (_message.Message,), {
  'DESCRIPTOR' : _SPIKESORTERDASHBOARDGENERALREC,
  '__module__' : 'spikesorter_pb2'
  # @@protoc_insertion_point(class_scope:allego.SpikeSorterDashboardGeneralRec)
  })
_sym_db.RegisterMessage(SpikeSorterDashboardGeneralRec)

SpikeSorterDashboardAI = _reflection.GeneratedProtocolMessageType('SpikeSorterDashboardAI', (_message.Message,), {
  'DESCRIPTOR' : _SPIKESORTERDASHBOARDAI,
  '__module__' : 'spikesorter_pb2'
  # @@protoc_insertion_point(class_scope:allego.SpikeSorterDashboardAI)
  })
_sym_db.RegisterMessage(SpikeSorterDashboardAI)

IndicoDashboardSiteStats = _reflection.GeneratedProtocolMessageType('IndicoDashboardSiteStats', (_message.Message,), {
  'DESCRIPTOR' : _INDICODASHBOARDSITESTATS,
  '__module__' : 'spikesorter_pb2'
  # @@protoc_insertion_point(class_scope:allego.IndicoDashboardSiteStats)
  })
_sym_db.RegisterMessage(IndicoDashboardSiteStats)

IndicoDashboardPortStats = _reflection.GeneratedProtocolMessageType('IndicoDashboardPortStats', (_message.Message,), {
  'DESCRIPTOR' : _INDICODASHBOARDPORTSTATS,
  '__module__' : 'spikesorter_pb2'
  # @@protoc_insertion_point(class_scope:allego.IndicoDashboardPortStats)
  })
_sym_db.RegisterMessage(IndicoDashboardPortStats)

IndicoDashboardSiteIndicators = _reflection.GeneratedProtocolMessageType('IndicoDashboardSiteIndicators', (_message.Message,), {
  'DESCRIPTOR' : _INDICODASHBOARDSITEINDICATORS,
  '__module__' : 'spikesorter_pb2'
  # @@protoc_insertion_point(class_scope:allego.IndicoDashboardSiteIndicators)
  })
_sym_db.RegisterMessage(IndicoDashboardSiteIndicators)

IndicoDashboardNeuronIndicators = _reflection.GeneratedProtocolMessageType('IndicoDashboardNeuronIndicators', (_message.Message,), {
  'DESCRIPTOR' : _INDICODASHBOARDNEURONINDICATORS,
  '__module__' : 'spikesorter_pb2'
  # @@protoc_insertion_point(class_scope:allego.IndicoDashboardNeuronIndicators)
  })
_sym_db.RegisterMessage(IndicoDashboardNeuronIndicators)

SpikeSorterDashboardSiteDesc = _reflection.GeneratedProtocolMessageType('SpikeSorterDashboardSiteDesc', (_message.Message,), {
  'DESCRIPTOR' : _SPIKESORTERDASHBOARDSITEDESC,
  '__module__' : 'spikesorter_pb2'
  # @@protoc_insertion_point(class_scope:allego.SpikeSorterDashboardSiteDesc)
  })
_sym_db.RegisterMessage(SpikeSorterDashboardSiteDesc)

SpikeSorterDashboardNeuronDesc = _reflection.GeneratedProtocolMessageType('SpikeSorterDashboardNeuronDesc', (_message.Message,), {
  'DESCRIPTOR' : _SPIKESORTERDASHBOARDNEURONDESC,
  '__module__' : 'spikesorter_pb2'
  # @@protoc_insertion_point(class_scope:allego.SpikeSorterDashboardNeuronDesc)
  })
_sym_db.RegisterMessage(SpikeSorterDashboardNeuronDesc)

SpikeSorterDashboardNeuronDetail = _reflection.GeneratedProtocolMessageType('SpikeSorterDashboardNeuronDetail', (_message.Message,), {
  'DESCRIPTOR' : _SPIKESORTERDASHBOARDNEURONDETAIL,
  '__module__' : 'spikesorter_pb2'
  # @@protoc_insertion_point(class_scope:allego.SpikeSorterDashboardNeuronDetail)
  })
_sym_db.RegisterMessage(SpikeSorterDashboardNeuronDetail)

SpikeSorterDashboardSiteDetail = _reflection.GeneratedProtocolMessageType('SpikeSorterDashboardSiteDetail', (_message.Message,), {
  'DESCRIPTOR' : _SPIKESORTERDASHBOARDSITEDETAIL,
  '__module__' : 'spikesorter_pb2'
  # @@protoc_insertion_point(class_scope:allego.SpikeSorterDashboardSiteDetail)
  })
_sym_db.RegisterMessage(SpikeSorterDashboardSiteDetail)


DESCRIPTOR._options = None
_SPIKESORTERSETDYNAMICREQUEST_VARIANTENTRY._options = None
_SPIKESORTERGETDYNAMICREPLY_VARIANTENTRY._options = None
_SPIKESORTERGETDASHBOARDREPLY_PORTSTATSENTRY._options = None
_SPIKESORTERGETDASHBOARDREPLY_SITEPANELENTRY._options = None
_SPIKESORTERGETDASHBOARDREPLY_NEURONPANELENTRY._options = None
# @@protoc_insertion_point(module_scope)
